@@ -1,6 +1,6 @@
 // Core.cc --- The main controller
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,20 +17,12 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: Core.cc 1578 2008-07-11 19:32:10Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "debug.hh"
 
-// FIXME: remove
-#if defined(PLATFORM_OS_WIN32)
-#define BACKEND
-#include "w32debug.hh"
-#endif
-
 #include <stdlib.h>
 #include <assert.h>
 #include <iostream>
@@ -70,8 +62,14 @@ static const char rcsid[] = "$Id: Core.cc 1578 2008-07-11 19:32:10Z rcaelers $";
 #endif
 
 #ifdef HAVE_DBUS
+#if defined(PLATFORM_OS_WIN32_NATIVE)
+#undef interface
+#endif
 #include "DBus.hh"
 #include "DBusException.hh"
+#ifdef HAVE_TESTS
+#include "Test.hh"
+#endif
 #endif
 
 Core *Core::instance = NULL;
@@ -263,8 +261,15 @@ Core::init_bus()
       dbus->connect(DBUS_PATH_WORKRAVE,
                     "org.workrave.ConfigInterface",
                     configurator);
+
+#ifdef HAVE_TESTS
+      dbus->register_object_path("/org/workrave/Workrave/Debug");
+      dbus->connect("/org/workrave/Workrave/Debug",
+                    "org.workrave.DebugInterface",
+                    Test::get_instance());
+#endif
     }
-  catch (DBusException &e)
+  catch (DBusException &)
     {
     }
 #endif
@@ -517,17 +522,11 @@ Core::get_operation_mode()
 OperationMode
 Core::set_operation_mode(OperationMode mode, bool persistent)
 {
-
-#ifdef PLATFORM_OS_WIN32
-// FIXME: debug, remove later
-if(mode == OPERATION_MODE_NORMAL)
-APPEND_TIME("Core::set_operation_mode()", "OPERATION_MODE_NORMAL ")
-else if (mode == OPERATION_MODE_SUSPENDED)
-APPEND_TIME("Core::set_operation_mode()", "OPERATION_MODE_SUSPENDED ")
-else if (mode == OPERATION_MODE_QUIET)
-APPEND_TIME("Core::set_operation_mode()", "OPERATION_MODE_QUIET ")
-#endif
-
+  TRACE_ENTER_MSG("Core::set_operation_mode",
+                  (mode == OPERATION_MODE_NORMAL ? "normal" :
+                   mode == OPERATION_MODE_SUSPENDED ? "suspended" :
+                   mode == OPERATION_MODE_QUIET ? "quiet" : "???"));
+  
   OperationMode previous_mode = operation_mode;
   
   if (operation_mode != mode)
@@ -571,7 +570,8 @@ APPEND_TIME("Core::set_operation_mode()", "OPERATION_MODE_QUIET ")
           core_event_listener->core_event_operation_mode_changed(mode);
         }
     }
-  
+
+  TRACE_RETURN(previous_mode);
   return previous_mode;
 }
 
@@ -733,21 +733,6 @@ Core::postpone_break(BreakId break_id)
 #ifdef HAVE_DISTRIBUTION
   send_break_control_message(break_id, BCM_POSTPONE);
 #endif
-
-  /* FIXME: move to frontend
-  if (resume_break != BREAK_ID_NONE &&
-      !breaks[resume_break].get_break_ignorable())
-    {
-      Timer *timer = breaks[resume_break].get_timer();
-      assert(timer != NULL);
-
-      if (timer->get_elapsed_time() > timer->get_limit())
-        {
-          force_break(resume_break, false);
-          resume_break = BREAK_ID_NONE;
-        }
-    }
-  */
 }
 
 
@@ -760,21 +745,6 @@ Core::skip_break(BreakId break_id)
 #ifdef HAVE_DISTRIBUTION
   send_break_control_message(break_id, BCM_SKIP);
 #endif
-
-  /* FIXME: move to frontend
-  if (resume_break != BREAK_ID_NONE &&
-      !breaks[resume_break].get_break_ignorable())
-    {
-      Timer *timer = breaks[resume_break].get_timer();
-      assert(timer != NULL);
-
-      if (timer->get_elapsed_time() > timer->get_limit())
-        {
-          force_break(resume_break, false);
-          resume_break = BREAK_ID_NONE;
-        }
-    }
-  */
 }
 
 
@@ -940,10 +910,10 @@ Core::process_state()
   // Default
   local_state = monitor->get_current_state();
 
-  map<std::string, int>::iterator i = external_activity.begin();
+  map<std::string, time_t>::iterator i = external_activity.begin();
   while (i != external_activity.end())
     {
-      map<std::string, int>::iterator next = i;
+      map<std::string, time_t>::iterator next = i;
       next++;
 
       if (i->second >= current_time)
@@ -960,7 +930,7 @@ Core::process_state()
 
   monitor_state = local_state;
 
-#if defined(HAVE_DISTRIBUTION) and !defined(NDEBUG)
+#if defined(HAVE_DISTRIBUTION) && !defined(NDEBUG)
   if (fake_monitor != NULL)
     {
       monitor_state = fake_monitor->get_current_state();
@@ -1016,7 +986,7 @@ void
 Core::get_timer_idle(BreakId id, int *value)
 {
   Timer *timer = get_timer(id);
-  *value = timer->get_elapsed_idle_time();
+  *value = (int) timer->get_elapsed_idle_time();
 }
 
 
@@ -1024,10 +994,17 @@ void
 Core::get_timer_elapsed(BreakId id, int *value)
 {
   Timer *timer = get_timer(id);
-  *value = timer->get_elapsed_time();
+  *value = (int) timer->get_elapsed_time();
 }
 
 
+void
+Core::get_timer_overdue(BreakId id, int *value)
+{
+  Timer *timer = get_timer(id);
+  *value = timer->get_total_overdue_time();
+}
+
 //! Processes all timers.
 void
 Core::process_timers()
@@ -1078,7 +1055,7 @@ Core::process_timers()
           (info.event == TIMER_EVENT_NATURAL_RESET ||
            info.event == TIMER_EVENT_RESET))
         {
-          statistics->set_counter(Statistics::STATS_VALUE_TOTAL_ACTIVE_TIME, info.elapsed_time);
+          statistics->set_counter(Statistics::STATS_VALUE_TOTAL_ACTIVE_TIME, (int) info.elapsed_time);
           statistics->start_new_day();
 
           daily_reset();
@@ -1097,8 +1074,8 @@ Core::process_timewarp()
   TRACE_ENTER("Core::process_timewarp");
   if (last_process_time != 0)
     {
-      int gap = current_time - 1 - last_process_time;
-      if (abs(gap) > 5)
+      time_t gap = current_time - 1 - last_process_time;
+      if (abs((int)gap) > 5)
         {
           if (!powersave)
             {
@@ -1107,10 +1084,10 @@ Core::process_timewarp()
 
               force_idle();
 
-              monitor->shift_time(gap);
+              monitor->shift_time((int)gap);
               for (int i = 0; i < BREAK_ID_SIZEOF; i++)
                 {
-                  breaks[i].get_timer()->shift_time(gap);
+                  breaks[i].get_timer()->shift_time((int)gap);
                 }
 
               monitor_state = ACTIVITY_IDLE;
@@ -1359,10 +1336,10 @@ Core::daily_reset()
       Timer *t = breaks[i].get_timer();
       assert(t != NULL);
 
-      int overdue = t->get_total_overdue_time();
+      time_t overdue = t->get_total_overdue_time();
 
       statistics->set_break_counter(((BreakId)i),
-                                    Statistics::STATS_BREAKVALUE_TOTAL_OVERDUE, overdue);
+                                    Statistics::STATS_BREAKVALUE_TOTAL_OVERDUE, (int)overdue);
 
       t->daily_reset_timer();
     }
@@ -1424,7 +1401,7 @@ Core::load_state()
   ifstream stateFile(ss.str().c_str());
 
   int version = 0;
-  bool ok = stateFile;
+  bool ok = stateFile.good();
 
   if (ok)
     {
@@ -1795,6 +1772,8 @@ Core::set_timer_state(PacketBuffer &buffer)
         {
           t->set_state_data(state_data);
         }
+
+      g_free(id);
     }
 
   TRACE_EXIT();
