@@ -1,6 +1,6 @@
 // DBus-template.hh --- DBUS template
 //
-// Copyright (C) 2007, 2008 Rob Caelers <robc@krandor.nl>
+// Copyright (C) 2007, 2008, 2009 Rob Caelers <robc@krandor.nl>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -16,8 +16,6 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Id: DBus.hh 1404 2008-01-07 20:48:30Z rcaelers $
-//
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -74,6 +72,7 @@ private:
   DBusMessage *IsTimerRunning(void *object, DBusMessage *message);
   DBusMessage *GetTimerIdle(void *object, DBusMessage *message);
   DBusMessage *GetTimerElapsed(void *object, DBusMessage *message);
+  DBusMessage *GetTimerOverdue(void *object, DBusMessage *message);
   DBusMessage *GetTime(void *object, DBusMessage *message);
   DBusMessage *IsActive(void *object, DBusMessage *message);
   DBusMessage *PostponeBreak(void *object, DBusMessage *message);
@@ -121,7 +120,7 @@ org_workrave_CoreInterface_Stub::call(int method_num, void *object, DBusMessage
 {
   DBusMessage *ret = NULL;
   
-  if (method_num >=0 && method_num < 10 )
+  if (method_num >=0 && method_num < 11 )
     {
       DBusMethod m = method_table[method_num];
       if (m != NULL)
@@ -256,7 +255,7 @@ org_workrave_CoreInterface_Stub::SetOperationMode(void *object, DBusMessage *mes
     {
       Core *dbus_object = (Core *) object;
       
-      OperationMode mode;
+      OperationMode mode       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -306,7 +305,7 @@ org_workrave_CoreInterface_Stub::GetOperationMode(void *object, DBusMessage *mes
     {
       Core *dbus_object = (Core *) object;
       
-      OperationMode mode;
+      OperationMode mode       ;
       
       ok = dbus_message_iter_init(message, &reader);
         
@@ -352,8 +351,8 @@ org_workrave_CoreInterface_Stub::ReportActivity(void *object, DBusMessage *messa
     {
       Core *dbus_object = (Core *) object;
       
-      std::string who;
-      bool act;
+      std::string who       ;
+      bool act       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -404,8 +403,8 @@ org_workrave_CoreInterface_Stub::IsTimerRunning(void *object, DBusMessage *messa
     {
       Core *dbus_object = (Core *) object;
       
-      BreakId timer_id;
-      bool value;
+      BreakId timer_id       ;
+      bool value       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -456,8 +455,8 @@ org_workrave_CoreInterface_Stub::GetTimerIdle(void *object, DBusMessage *message
     {
       Core *dbus_object = (Core *) object;
       
-      BreakId timer_id;
-      gint32 value;
+      BreakId timer_id       ;
+      gint32 value       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -508,8 +507,8 @@ org_workrave_CoreInterface_Stub::GetTimerElapsed(void *object, DBusMessage *mess
     {
       Core *dbus_object = (Core *) object;
       
-      BreakId timer_id;
-      gint32 value;
+      BreakId timer_id       ;
+      gint32 value       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -547,6 +546,58 @@ org_workrave_CoreInterface_Stub::GetTimerElapsed(void *object, DBusMessage *mess
 
   
 
+DBusMessage *
+org_workrave_CoreInterface_Stub::GetTimerOverdue(void *object, DBusMessage *message)
+{
+  DBusMessage *reply = NULL;
+
+  DBusMessageIter reader;
+  DBusMessageIter writer;
+  dbus_bool_t ok;
+
+  try
+    {
+      Core *dbus_object = (Core *) object;
+      
+      BreakId timer_id       ;
+      gint32 value       ;
+      
+      ok = dbus_message_iter_init(message, &reader);
+      if (!ok)
+        {
+          throw DBusSystemException("No parameters");
+        }
+        
+      get_break_id(&reader, &timer_id);
+
+      dbus_object->get_timer_overdue(        timer_id      , &value      );
+                                                              
+      reply = dbus_message_new_method_return(message);
+      if (reply == NULL)
+        {
+          throw DBusSystemException("Internal error");
+        }
+                                                              
+      dbus_message_iter_init_append(reply, &writer);
+      
+      put_int32(&writer, &value);
+  }
+  catch (DBusException)
+    {
+      if (reply != NULL)
+        {
+          dbus_message_unref(reply);
+        }
+
+      throw;
+    }
+                                                          
+  return reply;
+
+}
+
+  
+
 DBusMessage *
 org_workrave_CoreInterface_Stub::GetTime(void *object, DBusMessage *message)
 {
@@ -560,7 +611,7 @@ org_workrave_CoreInterface_Stub::GetTime(void *object, DBusMessage *message)
     {
       Core *dbus_object = (Core *) object;
       
-      gint32 value;
+      gint32 value       ;
       
       ok = dbus_message_iter_init(message, &reader);
         
@@ -606,7 +657,7 @@ org_workrave_CoreInterface_Stub::IsActive(void *object, DBusMessage *message)
     {
       Core *dbus_object = (Core *) object;
       
-      bool value;
+      bool value       ;
       
       ok = dbus_message_iter_init(message, &reader);
         
@@ -652,7 +703,7 @@ org_workrave_CoreInterface_Stub::PostponeBreak(void *object, DBusMessage *messag
     {
       Core *dbus_object = (Core *) object;
       
-      BreakId timer_id;
+      BreakId timer_id       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -702,7 +753,7 @@ org_workrave_CoreInterface_Stub::SkipBreak(void *object, DBusMessage *message)
     {
       Core *dbus_object = (Core *) object;
       
-      BreakId timer_id;
+      BreakId timer_id       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -831,6 +882,7 @@ org_workrave_CoreInterface_Stub::DBusMethod org_workrave_CoreInterface_Stub::met
   &org_workrave_CoreInterface_Stub::IsTimerRunning,
   &org_workrave_CoreInterface_Stub::GetTimerIdle,
   &org_workrave_CoreInterface_Stub::GetTimerElapsed,
+  &org_workrave_CoreInterface_Stub::GetTimerOverdue,
   &org_workrave_CoreInterface_Stub::GetTime,
   &org_workrave_CoreInterface_Stub::IsActive,
   &org_workrave_CoreInterface_Stub::PostponeBreak,
@@ -856,6 +908,9 @@ DBusIntrospect org_workrave_CoreInterface_Stub::method_introspect[] = {
   { "GetTimerElapsed",
     "in\0s\0timer_id\0out\0i\0value\0"
   },
+  { "GetTimerOverdue",
+    "in\0s\0timer_id\0out\0i\0value\0"
+  },
   { "GetTime",
     "out\0i\0value\0"
   },
@@ -890,6 +945,215 @@ DBusIntrospect org_workrave_CoreInterface_Stub::signal_introspect[] = {
 
  
 
+#if defined(HAVE_TESTS)
+
+using namespace workrave;
+
+#include "Test.hh"
+
+class org_workrave_DebugInterface_Stub : public DBusBindingBase, public org_workrave_DebugInterface
+{
+private:
+  typedef DBusMessage * (org_workrave_DebugInterface_Stub::*DBusMethod)(void *object, DBusMessage *message);
+
+  virtual DBusMessage *call(int method_num, void *object, DBusMessage *message);
+   
+  virtual DBusIntrospect *get_method_introspect()
+  {
+    return method_introspect;
+  }
+
+  virtual DBusIntrospect *get_signal_introspect()
+  {
+    return signal_introspect;
+  }
+
+public:
+  org_workrave_DebugInterface_Stub(DBus *dbus);
+  ~org_workrave_DebugInterface_Stub();
+  
+
+  
+private:
+  DBusMessage *Quit(void *object, DBusMessage *message);
+
+  void get_break_id(DBusMessageIter *reader, BreakId *result);
+  void put_break_id(DBusMessageIter *writer, const BreakId *result);
+
+
+
+  
+  static DBusMethod method_table[];
+  static DBusIntrospect method_introspect[];
+  static DBusIntrospect signal_introspect[];
+};
+
+
+org_workrave_DebugInterface *org_workrave_DebugInterface::instance(const DBus *dbus)
+{
+  org_workrave_DebugInterface_Stub *iface = NULL;
+  DBusBindingBase *binding = dbus->find_binding("org.workrave.DebugInterface");
+  
+  if (binding != NULL)
+    {
+      iface = dynamic_cast<org_workrave_DebugInterface_Stub *>(binding);
+    }
+
+  return iface;
+}
+
+org_workrave_DebugInterface_Stub::org_workrave_DebugInterface_Stub(DBus *dbus)
+  : DBusBindingBase(dbus)
+{
+}
+
+
+org_workrave_DebugInterface_Stub::~org_workrave_DebugInterface_Stub()
+{
+}
+
+DBusMessage *
+org_workrave_DebugInterface_Stub::call(int method_num, void *object, DBusMessage *message)
+{
+  DBusMessage *ret = NULL;
+  
+  if (method_num >=0 && method_num < 1 )
+    {
+      DBusMethod m = method_table[method_num];
+      if (m != NULL)
+        {
+          ret = (this->*m)(object, message);
+        }
+    }
+  
+  return ret;
+}
+ 
+
+void
+org_workrave_DebugInterface_Stub::get_break_id(DBusMessageIter *reader, BreakId *result)
+{
+  std::string value;
+	int argtype = dbus_message_iter_get_arg_type(reader);
+
+  if (argtype != DBUS_TYPE_STRING)
+		throw DBusTypeException("Type mismatch. Excepted string");
+
+  get_string(reader, &value);
+  
+  if ("microbreak" == value)
+    {
+      *result = BREAK_ID_MICRO_BREAK;
+    }
+  else if ("restbreak" == value)
+    {
+      *result = BREAK_ID_REST_BREAK;
+    }
+  else if ("dailylimit" == value)
+    {
+      *result = BREAK_ID_DAILY_LIMIT;
+    }
+  else
+    {
+      throw DBusTypeException("Illegal enum value");
+    }
+}
+
+void
+org_workrave_DebugInterface_Stub::put_break_id(DBusMessageIter *writer, const BreakId *result)
+{
+  string value;
+  switch (*result)
+    {
+    case BREAK_ID_MICRO_BREAK:
+      value = "microbreak";
+      break;
+    case BREAK_ID_REST_BREAK:
+      value = "restbreak";
+      break;
+    case BREAK_ID_DAILY_LIMIT:
+      value = "dailylimit";
+      break;
+    default:
+      throw DBusTypeException("Illegal enum value");
+    }
+        	
+  put_string(writer, &value);
+}
+
+
+
+
+
+
+
+DBusMessage *
+org_workrave_DebugInterface_Stub::Quit(void *object, DBusMessage *message)
+{
+  DBusMessage *reply = NULL;
+
+  DBusMessageIter reader;
+  DBusMessageIter writer;
+  dbus_bool_t ok;
+
+  try
+    {
+      Test *dbus_object = (Test *) object;
+      
+      
+      ok = dbus_message_iter_init(message, &reader);
+        
+
+      dbus_object->quit(       );
+                                                              
+      reply = dbus_message_new_method_return(message);
+      if (reply == NULL)
+        {
+          throw DBusSystemException("Internal error");
+        }
+                                                              
+      dbus_message_iter_init_append(reply, &writer);
+      
+  }
+  catch (DBusException)
+    {
+      if (reply != NULL)
+        {
+          dbus_message_unref(reply);
+        }
+
+      throw;
+    }
+                                                          
+  return reply;
+
+}
+
+  
+
+  
+org_workrave_DebugInterface_Stub::DBusMethod org_workrave_DebugInterface_Stub::method_table[] = {
+  &org_workrave_DebugInterface_Stub::Quit,
+};
+
+DBusIntrospect org_workrave_DebugInterface_Stub::method_introspect[] = {
+  { "Quit",
+    ""
+  },
+  { NULL,
+    NULL
+  }
+};
+  
+DBusIntrospect org_workrave_DebugInterface_Stub::signal_introspect[] = {
+  { NULL,
+    NULL
+  }
+};
+
+ #endif // defined(HAVE_TESTS)
+ 
+
 
 using namespace workrave;
 
@@ -997,9 +1261,9 @@ org_workrave_ConfigInterface_Stub::SetString(void *object, DBusMessage *message)
     {
       IConfigurator *dbus_object = (IConfigurator *) object;
       
-      std::string key;
-      std::string value;
-      bool success;
+      std::string key       ;
+      std::string value       ;
+      bool success       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -1051,9 +1315,9 @@ org_workrave_ConfigInterface_Stub::SetInt(void *object, DBusMessage *message)
     {
       IConfigurator *dbus_object = (IConfigurator *) object;
       
-      std::string key;
-      gint32 value;
-      bool success;
+      std::string key       ;
+      gint32 value       ;
+      bool success       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -1105,9 +1369,9 @@ org_workrave_ConfigInterface_Stub::SetBool(void *object, DBusMessage *message)
     {
       IConfigurator *dbus_object = (IConfigurator *) object;
       
-      std::string key;
-      bool value;
-      bool success;
+      std::string key       ;
+      bool value       ;
+      bool success       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -1159,9 +1423,9 @@ org_workrave_ConfigInterface_Stub::SetDouble(void *object, DBusMessage *message)
     {
       IConfigurator *dbus_object = (IConfigurator *) object;
       
-      std::string key;
-      double value;
-      bool success;
+      std::string key       ;
+      double value       ;
+      bool success       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -1213,9 +1477,9 @@ org_workrave_ConfigInterface_Stub::GetString(void *object, DBusMessage *message)
     {
       IConfigurator *dbus_object = (IConfigurator *) object;
       
-      std::string key;
-      bool found;
-      std::string value;
+      std::string key       ;
+      bool found       ;
+      std::string value       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -1267,9 +1531,9 @@ org_workrave_ConfigInterface_Stub::GetInt(void *object, DBusMessage *message)
     {
       IConfigurator *dbus_object = (IConfigurator *) object;
       
-      std::string key;
-      gint32 value;
-      bool found;
+      std::string key       ;
+      gint32 value       ;
+      bool found       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -1321,9 +1585,9 @@ org_workrave_ConfigInterface_Stub::GetBool(void *object, DBusMessage *message)
     {
       IConfigurator *dbus_object = (IConfigurator *) object;
       
-      std::string key;
-      bool value;
-      bool found;
+      std::string key       ;
+      bool value       ;
+      bool found       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -1375,9 +1639,9 @@ org_workrave_ConfigInterface_Stub::GetDouble(void *object, DBusMessage *message)
     {
       IConfigurator *dbus_object = (IConfigurator *) object;
       
-      std::string key;
-      double value;
-      bool found;
+      std::string key       ;
+      double value       ;
+      bool found       ;
       
       ok = dbus_message_iter_init(message, &reader);
       if (!ok)
@@ -1469,5 +1733,8 @@ DBusIntrospect org_workrave_ConfigInterface_Stub::signal_introspect[] = {
 void init_DBusWorkrave(DBus *dbus)
 {
   dbus->register_binding("org.workrave.CoreInterface", new org_workrave_CoreInterface_Stub(dbus));
+#if defined(HAVE_TESTS)
+  dbus->register_binding("org.workrave.DebugInterface", new org_workrave_DebugInterface_Stub(dbus));
+#endif // defined(HAVE_TESTS)
   dbus->register_binding("org.workrave.ConfigInterface", new org_workrave_ConfigInterface_Stub(dbus));
 }
