@@ -1,25 +1,28 @@
 // DistributionManager.cc
 //
-// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
-// This program is free software; you can redistribute it and/or modify
+// This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2, or (at your option)
-// any later version.
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-
-static const char rcsid[] = "$Id: DistributionManager.cc 1467 2008-03-08 22:28:03Z rcaelers $";
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+//
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifdef HAVE_DISTRIBUTION
+
 #include "debug.hh"
 #include <algorithm>
 #include <assert.h>
@@ -562,7 +565,7 @@ DistributionManager::config_changed_notify(const string &key)
 
 //! 
 void
-DistributionManager::log(char *fmt, ...)
+DistributionManager::log(const char *fmt, ...)
 {
   va_list va;
 
@@ -807,7 +810,7 @@ DistributionManager::get_username() const
 void
 DistributionManager::set_username(string name)
 {
-  configurator->set_value(CoreConfig::CFG_KEY_DISTRIBUTION + CoreConfig::CFG_KEY_DISTRIBUTION_TCP_USERNAME, name);
+  configurator->set_value(CoreConfig::CFG_KEY_DISTRIBUTION_TCP_USERNAME, name);
 }
 
 
@@ -888,3 +891,6 @@ DistributionManager::set_reconnect_interval(int v)
 {
   configurator->set_value(CoreConfig::CFG_KEY_DISTRIBUTION_TCP_INTERVAL, v);
 }
+
+
+#endif
