@@ -3,24 +3,26 @@
 // Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
-// This program is free software; you can redistribute it and/or modify
+// This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2, or (at your option)
-// any later version.
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-static const char rcsid[] = "$Id: DistributionSocketLink.cc 1467 2008-03-08 22:28:03Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifdef HAVE_DISTRIBUTION
+
 #include "debug.hh"
 #include <assert.h>
 
@@ -734,7 +736,8 @@ DistributionSocketLink::remove_peer_clients(Client *client)
 void
 DistributionSocketLink::close_client(Client *client, bool reconnect /* = false*/)
 {
-  TRACE_ENTER_MSG("DistributionSocketLink::close_client", client->id << " " << reconnect);
+  TRACE_ENTER_MSG("DistributionSocketLink::close_client", 
+	  (client->id != NULL ? client->id : "Unknown") << " " << reconnect);
 
   if (client == master_client)
     {
@@ -1308,7 +1311,7 @@ DistributionSocketLink::send_signoff(Client *to, Client *signedoff_client)
 
   if (signedoff_client != NULL)
     {
-      TRACE_MSG("remote client " << signedoff_client->id);
+	  TRACE_MSG("remote client " << (signedoff_client->id != NULL ? signedoff_client->id : "?"));
       packet.pack_string(signedoff_client->id);
     }
   else
@@ -1319,7 +1322,7 @@ DistributionSocketLink::send_signoff(Client *to, Client *signedoff_client)
 
   if (to != NULL)
     {
-      TRACE_MSG("sending to " << to->id);
+      TRACE_MSG("sending to " << (to->id != NULL ? to->id : "?"));
       send_packet(to, packet);
     }
   else
@@ -1609,6 +1612,9 @@ DistributionSocketLink::handle_client_list(PacketBuffer &packet, Client *client,
       // Skip trailing junk...
       size -= (packet.bytes_read() - pos);
       packet.skip(size);
+
+      g_free(name);
+      g_free(id);
     }
 
 
@@ -2190,3 +2196,5 @@ DistributionSocketLink::config_changed_notify(const string &key)
   (void) key;
   read_configuration();
 }
+
+#endif
