@@ -1,20 +1,20 @@
 // IdleLogManager.cc
 //
-// Copyright (C) 2003, 2004, 2005, 2007 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2003, 2004, 2005, 2007, 2009 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
-// This program is free software; you can redistribute it and/or modify
+// This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2, or (at your option)
-// any later version.
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
-
-static const char rcsid[] = "$Id: IdleLogManager.cc 1356 2007-10-22 18:22:13Z rcaelers $";
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -26,7 +26,10 @@ static const char rcsid[] = "$Id: IdleLogManager.cc 1356 2007-10-22 18:22:13Z rc
 #include <fstream>
 #include <sstream>
 #include <assert.h>
+
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 
 #include "Util.hh"
 #include "IdleLogManager.hh"
@@ -36,8 +39,7 @@ static const char rcsid[] = "$Id: IdleLogManager.cc 1356 2007-10-22 18:22:13Z rc
 #define IDLELOG_MAXSIZE     (4000)
 #define IDLELOG_MAXAGE    (12 * 60 * 60)
 #define IDLELOG_INTERVAL    (30 * 60)
-#define IDLELOG_OLDVERSION  (1)
-#define IDLELOG_VERSION   (2)
+#define IDLELOG_VERSION   (3)
 #define IDLELOG_INTERVAL_SIZE (17)
 
 
@@ -145,7 +147,7 @@ IdleLogManager::terminate()
 void
 IdleLogManager::expire()
 {
-  int current_time = time_source->get_time();
+  time_t current_time = time_source->get_time();
   if (last_expiration_time == 0)
     {
       last_expiration_time = current_time +  IDLELOG_INTERVAL;
@@ -171,9 +173,9 @@ IdleLogManager::expire(ClientInfo &info)
       info.idlelog.resize(IDLELOG_MAXSIZE);
     }
   
-  int current_time = time_source->get_time();
+  time_t current_time = time_source->get_time();
   int count = 0;
-  for (IdleLogRIter i = info.idlelog.rend(); i != info.idlelog.rbegin(); i++)
+  for (IdleLogRIter i = info.idlelog.rbegin(); i != info.idlelog.rend(); i++)
     {
       IdleInterval &idle = info.idlelog.back();
       if (idle.end_idle_time < current_time - IDLELOG_MAXAGE)
@@ -202,7 +204,7 @@ IdleLogManager::update_idlelog(ClientInfo &info, ActivityState state, bool maste
   // Did the state/master status change?
   bool changed = state != info.state; // RC: removed... || master != info.master;
 
-  int current_time = time_source->get_time();
+  time_t current_time = time_source->get_time();
   IdleInterval *idle = &(info.current_interval);
   idle->end_time = current_time;
   
@@ -239,15 +241,18 @@ IdleLogManager::update_idlelog(ClientInfo &info, ActivityState state, bool maste
           // State remained idle. Update end time of idle interval.
           idle->end_idle_time = current_time;
 
-          int total_idle = idle->end_idle_time - idle->begin_time;
-          if (total_idle >= 10)
+          if (info.idlelog.size() > 0)
             {
-              IdleInterval *save_interval = &(info.idlelog.front());
-              if (save_interval->to_be_saved)
+              time_t total_idle = idle->end_idle_time - idle->begin_time;
+              if (total_idle >= 10)
                 {
-                  TRACE_MSG("Saving");
-                  update_idlelog(info, *save_interval);
-                  save_interval->to_be_saved = false;
+                  IdleInterval *save_interval = &(info.idlelog.front());
+                  if (save_interval->to_be_saved)
+                    {
+                      TRACE_MSG("Saving");
+                      update_idlelog(info, *save_interval);
+                      save_interval->to_be_saved = false;
+                    }
                 }
             }
         }
@@ -260,7 +265,7 @@ IdleLogManager::update_idlelog(ClientInfo &info, ActivityState state, bool maste
           
           idle->end_idle_time = current_time;
 
-          int total_idle = idle->end_idle_time - idle->begin_time;
+          time_t total_idle = idle->end_idle_time - idle->begin_time;
           if (total_idle < 10 && info.idlelog.size() > 1)
             {
               // Idle period too short. remove it. and reuse previous
@@ -293,30 +298,30 @@ IdleLogManager::update_idlelog(ClientInfo &info, ActivityState state, bool maste
 
 
 //! Returns the total active time of all clients.
-int
+time_t
 IdleLogManager::compute_total_active_time()
 {
   TRACE_ENTER("IdleLogManager::compute_total_active_time");
-  int current_time = time_source->get_time();
-  int active_time = 0;
+  time_t current_time = time_source->get_time();
+  time_t active_time = 0;
   for (ClientMapIter it = clients.begin(); it != clients.end(); it++)
     {
       ClientInfo &info = (*it).second;
       info.update_active_time(current_time);
       active_time += info.total_active_time;
     }
-  return active_time;
   TRACE_EXIT();
+  return active_time;
 }
 
 
 //! Returns the active time since an idle period of a least the specified amount of time.
-int
+time_t
 IdleLogManager::compute_active_time(int length)
 {
   TRACE_ENTER("IdleLogManager::compute_active_time");
 
-  int current_time = time_source->get_time();
+  time_t current_time = time_source->get_time();
   
   // Number of client.
   int size = clients.size();
@@ -325,7 +330,7 @@ IdleLogManager::compute_active_time(int length)
   IdleLogIter *iterators = new IdleLogIter[size];
   IdleLogIter *end_iterators = new IdleLogIter[size];
   bool *at_end = new bool[size];
-  int *active_time = new int[size];
+  time_t *active_time = new time_t[size];
   
   // Init data for all clients.
   int count = 0;
@@ -415,7 +420,7 @@ IdleLogManager::compute_active_time(int length)
         }
     }
 
-  int total_active_time = 0;
+  time_t total_active_time = 0;
   for (int i = 0; i < size; i++)
     {
       TRACE_MSG("active time of " << i << " = " << active_time[i]);
@@ -435,12 +440,12 @@ IdleLogManager::compute_active_time(int length)
 
 
 //! Computes the current idle time.
-int
+time_t
 IdleLogManager::compute_idle_time()
 {
   TRACE_ENTER("IdleLogManager::compute_idle_time");
 
-  int current_time = time_source->get_time();
+  time_t current_time = time_source->get_time();
   
   int count = 0;
   time_t latest_start_time = 0;
@@ -484,10 +489,10 @@ IdleLogManager::pack_idle_interval(PacketBuffer &buffer, const IdleInterval &idl
   
   buffer.reserve_size(pos);
   buffer.pack_byte(IDLELOG_VERSION);
-  buffer.pack_ulong(idle.begin_time);
-  buffer.pack_ulong(idle.end_idle_time);
-  buffer.pack_ulong(idle.end_time);
-  buffer.pack_ushort(idle.active_time);
+  buffer.pack_ulong((guint32)idle.begin_time);
+  buffer.pack_ulong((guint32)idle.end_idle_time);
+  buffer.pack_ulong((guint32)idle.end_time);
+  buffer.pack_ushort((guint32)idle.active_time);
   buffer.update_size(pos);
 }
 
@@ -521,16 +526,16 @@ IdleLogManager::unpack_idle_interval(PacketBuffer &buffer, IdleInterval &idle, t
 void
 IdleLogManager::pack_idlelog(PacketBuffer &buffer, const ClientInfo &ci) const
 {
-  int current_time = time_source->get_time();
+  time_t current_time = time_source->get_time();
 
   // Add size.
   int pos = 0;
   buffer.reserve_size(pos);
   
   // Pack
-  buffer.pack_ulong(current_time);
+  buffer.pack_ulong((guint32)current_time);
   buffer.pack_string(ci.client_id.c_str());
-  buffer.pack_ulong(ci.total_active_time);
+  buffer.pack_ulong((guint32)ci.total_active_time);
   buffer.pack_byte(ci.master);
   buffer.pack_byte(ci.state);
   buffer.pack_ushort(ci.idlelog.size());
@@ -559,7 +564,7 @@ IdleLogManager::unpack_idlelog(PacketBuffer &buffer, ClientInfo &ci,
         }
       
       ci.total_active_time = buffer.unpack_ulong();
-      ci.master = (bool) buffer.unpack_byte();
+      ci.master = buffer.unpack_byte() != 0;
       ci.state = (ActivityState) buffer.unpack_byte();
       
       num_intervals = buffer.unpack_ushort();
@@ -639,7 +644,7 @@ IdleLogManager::save_index()
   ss << Util::get_home_directory();
   ss << "idlelog.idx" << ends;
 
-  ofstream file(ss.str().c_str());
+  ofstream file(ss.str().c_str(), ios::binary);
   file.write(buffer.get_buffer(), buffer.bytes_written());
   file.close();
 
@@ -665,7 +670,7 @@ IdleLogManager::load_index()
       TRACE_MSG("File exists - ok");
 
       // Open file
-      ifstream file(ss.str().c_str());
+      ifstream file(ss.str().c_str(), ios::binary);
 
       // get file size using buffer's members
       filebuf *pbuf=file.rdbuf();
@@ -713,7 +718,7 @@ IdleLogManager::load_index()
           
           g_free(id);
         }
-      else if (version == IDLELOG_OLDVERSION)
+      else
         {
           TRACE_MSG("Old version - deleting logs of old version");
 
@@ -756,7 +761,7 @@ IdleLogManager::save_idlelog(ClientInfo &info)
   ss << Util::get_home_directory();
   ss << "idlelog." << info.client_id << ".log" << ends;
 
-  ofstream file(ss.str().c_str());
+  ofstream file(ss.str().c_str(), ios::binary);
   file.write(buffer.get_buffer(), buffer.bytes_written());
   file.close();
 }
@@ -768,14 +773,14 @@ IdleLogManager::load_idlelog(ClientInfo &info)
 {
   TRACE_ENTER("IdleLogManager::load_idlelog()");
 
-  int current_time = time_source->get_time();
+  time_t current_time = time_source->get_time();
 
   stringstream ss;
   ss << Util::get_home_directory();
   ss << "idlelog." << info.client_id << ".log" << ends;
 
   // Open file
-  ifstream file(ss.str().c_str());
+  ifstream file(ss.str().c_str(), ios::binary);
 
   // get file size using buffer's members
   filebuf *pbuf=file.rdbuf();
@@ -814,8 +819,11 @@ IdleLogManager::load_idlelog(ClientInfo &info)
             }
         }
 
-      IdleInterval &idle = info.idlelog.back();
-      idle.begin_time = 1;
+	  if (info.idlelog.size() > 0) 
+	    {
+           IdleInterval &idle = info.idlelog.back();
+           idle.begin_time = 1;
+	    }
     }
 
   dump_idlelog(info);
@@ -869,7 +877,7 @@ IdleLogManager::update_idlelog(ClientInfo &info, const IdleInterval &idle)
   ss << Util::get_home_directory();
   ss << "idlelog." << info.client_id << ".log" << ends;
 
-  ofstream file(ss.str().c_str(), ios::app);
+  ofstream file(ss.str().c_str(), ios::app | ios::binary);
   file.write(buffer.get_buffer(), buffer.bytes_written());
   file.close();
 
@@ -940,7 +948,7 @@ IdleLogManager::signon_remote_client(string client_id)
 {
   TRACE_ENTER_MSG("signon_remote_client", client_id);
 
-  int current_time = time_source->get_time();
+  time_t current_time = time_source->get_time();
   
   ClientInfo &info = clients[client_id];
   info.idlelog.push_front(IdleInterval(1, current_time));
@@ -1036,7 +1044,7 @@ IdleLogManager::fix_idlelog(ClientInfo &info)
 {
   TRACE_ENTER("IdleLogManager::fix_idlelog");
   
-  int current_time = time_source->get_time();
+  time_t current_time = time_source->get_time();
   info.update_active_time(current_time);
 
   time_t next_time = -1;
