@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: Statistics.cc 1585 2008-07-13 08:59:32Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -213,6 +211,8 @@ Statistics::day_to_remote_history(DailyStatsImpl *stats)
 
       dist_manager->broadcast_client_message(DCM_STATS, state_packet);
     }
+#else
+  (void) stats;
 #endif
 }
 
@@ -370,7 +370,7 @@ Statistics::load(ifstream &infile, bool history)
 
   DailyStatsImpl *stats = NULL;
 
-  bool ok = infile;
+  bool ok = infile.good();
 
   if (ok)
     {
@@ -415,7 +415,6 @@ Statistics::load(ifstream &infile, bool history)
                   return;
                 }
 
-              // FIXME: leak
               stats = new DailyStatsImpl();
 
               ss >> stats->start.tm_mday
@@ -679,7 +678,7 @@ Statistics::update_current_day(bool active)
       // Collect total active time from dialy limit timer.
       Timer *t = core->get_break(BREAK_ID_DAILY_LIMIT)->get_timer();
       assert(t != NULL);
-      current_day->misc_stats[STATS_VALUE_TOTAL_ACTIVE_TIME] = t->get_elapsed_time();
+      current_day->misc_stats[STATS_VALUE_TOTAL_ACTIVE_TIME] = (int)t->get_elapsed_time();
 
       if (active)
         {
@@ -693,10 +692,10 @@ Statistics::update_current_day(bool active)
           Timer *t = core->get_break(BreakId(i))->get_timer();
           assert(t != NULL);
 
-          int overdue = t->get_total_overdue_time();
+          time_t overdue = t->get_total_overdue_time();
 
           set_break_counter(((BreakId)i),
-                            Statistics::STATS_BREAKVALUE_TOTAL_OVERDUE, overdue);
+                            Statistics::STATS_BREAKVALUE_TOTAL_OVERDUE, (int)overdue);
         }
 
 
