@@ -1,6 +1,6 @@
 // Timer.cc --- break timer
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2006, 2007, 2008 Rob Caelers <robc@krandor.nl>
+// Copyright (C) 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009 Rob Caelers <robc@krandor.nl>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: Timer.cc 1539 2008-06-08 19:48:14Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -28,6 +26,7 @@ static const char rcsid[] = "$Id: Timer.cc 1539 2008-06-08 19:48:14Z rcaelers $"
 #include <sstream>
 #include <stdio.h>
 #include <math.h>
+#include <time.h>
 
 #include "CoreFactory.hh"
 #include "ICore.hh"
@@ -41,6 +40,14 @@ static const char rcsid[] = "$Id: Timer.cc 1539 2008-06-08 19:48:14Z rcaelers $"
 using namespace std;
 using namespace workrave;
 
+#ifdef HAVE_EXTERN_TIMEZONE
+#  ifndef HAVE_EXTERN_TIMEZONE_DEFINED
+extern long timezone;
+#  endif
+#else
+static int timezone = 0;
+#endif
+
 //! Constructs a new break timer.
 /*!
  *  \param time_source source of the current time that will be used by the timer.
@@ -251,7 +258,7 @@ Timer::set_activity_sensitive(bool a)
       // If timer is made insensitive, start it if
       // it has some elasped time. Otherwise a daily limit
       // will never start (well, not until it resets...)
-      int elasped = get_elapsed_time();
+      time_t elasped = get_elapsed_time();
       if (elasped > 0 && elasped < limit_interval)
         {
           activity_state = ACTIVITY_ACTIVE;
@@ -571,6 +578,15 @@ Timer::freeze_timer(bool freeze)
             }
         }
     }
+
+  //test fix for Bug 746 -  Micro-break not counting down
+  if (timer_enabled && !freeze && timer_frozen && timer_state == STATE_RUNNING && !last_start_time && !activity_sensitive )
+    {
+      last_start_time = core->get_time();
+      elapsed_idle_time = 0;
+      compute_next_limit_time();
+    }
+
   timer_frozen = freeze;
   TRACE_EXIT();
 }
@@ -613,14 +629,18 @@ Timer::get_elapsed_time() const
 time_t
 Timer::get_total_overdue_time() const
 {
+  TRACE_ENTER("Timer::get_total_overdue_time");
   time_t ret = total_overdue_time;
   time_t elapsed = get_elapsed_time();
 
+  TRACE_MSG(ret << " " << elapsed);
+  
   if (elapsed > limit_interval)
     {
       ret += (elapsed - limit_interval);
     }
 
+  TRACE_EXIT();
   return ret;
 }
 
@@ -668,6 +688,11 @@ void
 Timer::process(ActivityState new_activity_state, TimerInfo &info)
 {
   TRACE_ENTER_MSG("Timer::Process", timer_id << timer_id << " " << new_activity_state);
+  
+  // msvc can't handle std::string conditional tracepoints. use TRACE as the conditional
+  bool TRACE = ( timer_id == "micro_pause" || timer_id == "rest_break" );
+  (void) TRACE;
+  
   time_t current_time= core->get_time();
 
   // Default event to return.
@@ -683,23 +708,6 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
   TRACE_MSG("next_reset_time " << next_reset_time);
   TRACE_MSG("time " << current_time);
   
-  const time_t now = core->get_time();
-  struct tm *tmnow = localtime(&now);
-
-  TRACE_MSG(tmnow->tm_mday << " "
-            << tmnow->tm_mon << " "
-            << tmnow->tm_year << " "
-            << tmnow->tm_hour << " "
-            << tmnow->tm_min << " "
-            << tmnow->tm_min << " "
-            << tmnow->tm_isdst << " "
-#ifdef PLATFORM_OS_UNIX            
-            << tmnow->tm_gmtoff << " "
-#endif            
-            << tzname[0] << " " 
-            << tzname[1]);
-
-  
   if (activity_sensitive)
     {
       TRACE_MSG("is activity sensitive");
@@ -936,23 +944,6 @@ Timer::deserialize_state(const std::string &state, int version)
 
   // lastReset -= tz;
 
-  time_t xx = lastReset - tz;
-  struct tm *lt = localtime(&xx);
-
-  TRACE_MSG(lt->tm_mday << " "
-            << lt->tm_mon << " "
-            << lt->tm_year << " "
-            << lt->tm_hour << " "
-            << lt->tm_min << " "
-            << lt->tm_isdst << " "
-#ifdef PLATFORM_OS_UNIX            
-            << lt->tm_gmtoff << " "
-#endif
-            << tzname[0] << " " 
-            << tzname[1] << " " 
-            << timezone << " "
-            << daylight);
-  
   TRACE_MSG(si << " " << llt << " " << lle);
   TRACE_MSG(snooze_inhibited);
 
@@ -992,16 +983,11 @@ Timer::deserialize_state(const std::string &state, int version)
 void
 Timer::set_state(int elapsed, int idle, int overdue)
 {
-  TRACE_ENTER("Timer::set_state");
+  TRACE_ENTER_MSG("Timer::set_state", elapsed << " " << idle << " " << overdue);
 
   elapsed_time = elapsed;
   elapsed_idle_time = idle;
 
-  if (overdue >= 0)
-    {
-      total_overdue_time = overdue;
-    }
-  
   if (last_start_time != 0)
     {
       last_start_time = core->get_time();
@@ -1017,6 +1003,15 @@ Timer::set_state(int elapsed, int idle, int overdue)
       elapsed_idle_time = autoreset_interval;
     }
 
+  if (overdue != -1)
+    {
+      total_overdue_time = overdue;
+      if (get_elapsed_time() > limit_interval)
+        {
+          total_overdue_time -= (get_elapsed_time() - limit_interval);
+        }
+    }
+  
   compute_next_reset_time();
   compute_next_limit_time();
   compute_next_predicate_reset_time();
