@@ -4,7 +4,7 @@
 #ifdef __cplusplus
 extern "C"
 {
-#endif	/* __cplusplus */
+#endif  /* __cplusplus */
 
 
 #include <windows.h>
@@ -14,14 +14,17 @@ extern "C"
 #include <stdio.h>
 #include <imagehlp.h>
 
-EXCEPTION_DISPOSITION __cdecl 
-exception_handler(struct _EXCEPTION_RECORD *exception_record, 
-                  void *establisher_frame, 
-                  struct _CONTEXT *context_record, 
+void
+print_module_list(FILE *log);
+
+EXCEPTION_DISPOSITION __cdecl
+exception_handler(struct _EXCEPTION_RECORD *exception_record,
+                  void *establisher_frame,
+                  struct _CONTEXT *context_record,
                   void *dispatcher_context);
 
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
-  
+
 #endif
