@@ -17,11 +17,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: harpoon.h 1351 2007-10-14 20:56:54Z rcaelers $
  */
 #ifndef HARPOON_H
 #define HARPOON_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <windows.h>
 #include <mbstring.h>
 
@@ -109,11 +112,24 @@ HARPOON_API char *_mbstrncpy_lowercase( const char *, const char *, int );
 }
 #endif
 
+#ifndef XBUTTON1
 #define XBUTTON1 0x0001
-#define XBUTTON2 0x0002
+#endif
 
+#ifndef XBUTTON2
+#define XBUTTON2 0x0002
+#endif
+
+#ifndef PLATFORM_OS_WIN32_NATIVE
+
+#ifndef WM_XBUTTONDOWN
 #define WM_XBUTTONDOWN 523
+#endif
+
+#ifndef WM_XBUTTONUP
 #define WM_XBUTTONUP 524
+#endif
+
 #define WM_XBUTTONDBLCLK 525
 #define WM_MOUSEHWHEEL 526
 
@@ -127,4 +143,6 @@ HARPOON_API char *_mbstrncpy_lowercase( const char *, const char *, int );
 #define WM_UNICHAR 265
 #define WM_APPCOMMAND 793
 
+#endif
+
 #endif /* HARPOON_H */
