@@ -1,6 +1,6 @@
 // SoundPlayer.cc --- Sound player
 //
-// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: SoundPlayer.cc 1581 2008-07-12 19:20:28Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -26,35 +24,41 @@ static const char rcsid[] = "$Id: SoundPlayer.cc 1581 2008-07-12 19:20:28Z rcael
 #include "debug.hh"
 #include "nls.h"
 
+#ifdef HAVE_REALPATH
+#include <limits.h>
+#include <stdlib.h>
+#endif
+
 #include <list>
 
-#include "SoundPlayer.hh"
 #include "Thread.hh"
+
 #include "Sound.hh"
+#include "SoundPlayer.hh"
+#include "ISoundDriver.hh"
 
 #include "IConfigurator.hh"
 #include "CoreFactory.hh"
 #include "Util.hh"
 
-#ifdef HAVE_GNOME
-#include <gdk/gdk.h>
+#if defined HAVE_GSTREAMER
+#include "GstSoundPlayer.hh"
+#elif defined HAVE_GNOME
 #include "GnomeSoundPlayer.hh"
-#endif
-#ifdef HAVE_KDE
+#elif defined HAVE_KDE
 #include "KdeSoundPlayer.hh"
-#endif
-#ifdef PLATFORM_OS_UNIX
+#elif defined PLATFORM_OS_UNIX
 #include <X11/Xlib.h>
-#endif
-#ifdef PLATFORM_OS_WIN32
+#elif defined PLATFORM_OS_WIN32
 #include <windows.h>
 #include "W32SoundPlayer.hh"
-#endif
-#ifdef PLATFORM_OS_OSX
+#include "W32DirectSoundPlayer.hh"
+#elif defined PLATFORM_OS_OSX
 #include "OSXSoundPlayer.hh"
 #endif
-#ifdef HAVE_GSTREAMER
-#include "GstSoundPlayer.hh"
+
+#if defined HAVE_GNOME
+#include <gdk/gdk.h>
 #endif
 
 const char *SoundPlayer::CFG_KEY_SOUND_ENABLED = "sound/enabled";
@@ -213,6 +217,12 @@ static short exercises_ended_beeps[][2]=
     { 0, 0 },
 };
 
+static short exercises_step_beeps[][2]=
+{
+    { 320, 70 },
+    { 0, 0 },
+};
+
 static short (*beep_map[])[2] =
 {
   prelude_beeps,
@@ -223,7 +233,8 @@ static short (*beep_map[])[2] =
   micro_break_end_beeps,
   daily_limit_beeps,
   exercise_ended_beeps,
-  exercises_ended_beeps
+  exercises_ended_beeps,
+  exercises_step_beeps
 };
 
 
@@ -296,22 +307,22 @@ SpeakerPlayer::run()
 SoundPlayer::SoundPlayer()
 {
   driver =
-#if defined(PLATFORM_OS_WIN32)
-     new W32SoundPlayer()
-#elif defined(HAVE_KDE)
-     new KdeSoundPlayer()
-#elif defined(HAVE_GSTREAMER)
+#if defined HAVE_GSTREAMER
      new GstSoundPlayer()
-#elif defined(HAVE_GNOME)
+#elif defined HAVE_GNOME
      new GnomeSoundPlayer()
-#elif defined(PLATFORM_OS_OSX)
+#elif defined HAVE_KDE
+     new KdeSoundPlayer()
+#elif defined PLATFORM_OS_WIN32
+     new W32DirectSoundPlayer()
+#elif defined PLATFORM_OS_OSX
      new OSXSoundPlayer()
 #else
 #  warning Sound card support disabled.
      NULL
 #endif
     ;
-  register_sound_events();
+
 }
 
 SoundPlayer::~SoundPlayer()
@@ -320,6 +331,13 @@ SoundPlayer::~SoundPlayer()
 }
 
 
+void
+SoundPlayer::init()
+{
+  driver->init();
+  register_sound_events();
+}
+
 void
 SoundPlayer::register_sound_events(string theme)
 {
@@ -387,28 +405,31 @@ SoundPlayer::activate_theme(const Theme &theme, bool force)
 void
 SoundPlayer::sync_settings()
 {
-  for (unsigned int i = 0; i < sizeof(sound_registry)/sizeof(sound_registry[0]); i++)
+  if (driver != NULL)
     {
-      SoundRegistry *snd = &sound_registry[i];
-
-      bool enabled = false;
-      bool valid = driver->get_sound_enabled((SoundEvent)i, enabled);
-
-      if (valid)
+      for (unsigned int i = 0; i < sizeof(sound_registry)/sizeof(sound_registry[0]); i++)
         {
-          CoreFactory::get_configurator()->set_value(string(SoundPlayer::CFG_KEY_SOUND_EVENTS) +
-                                                     snd->id +
-                                                     SoundPlayer::CFG_KEY_SOUND_EVENTS_ENABLED,
-                                                     enabled);
-        }
+          SoundRegistry *snd = &sound_registry[i];
+
+          bool enabled = false;
+          bool valid = driver->get_sound_enabled((SoundEvent)i, enabled);
+
+          if (valid)
+            {
+              CoreFactory::get_configurator()->set_value(string(SoundPlayer::CFG_KEY_SOUND_EVENTS) +
+                                                         snd->id +
+                                                         SoundPlayer::CFG_KEY_SOUND_EVENTS_ENABLED,
+                                                         enabled);
+            }
       
-      string wav_file;
-      valid = driver->get_sound_wav_file((SoundEvent)i, wav_file);
-      if (valid)
-        {
-          CoreFactory::get_configurator()->set_value(string(SoundPlayer::CFG_KEY_SOUND_EVENTS) +
-                                                     snd->id,
-                                                     wav_file);
+          string wav_file;
+          valid = driver->get_sound_wav_file((SoundEvent)i, wav_file);
+          if (valid)
+            {
+              CoreFactory::get_configurator()->set_value(string(SoundPlayer::CFG_KEY_SOUND_EVENTS) +
+                                                         snd->id,
+                                                         wav_file);
+            }
         }
     }
 }
@@ -422,7 +443,7 @@ SoundPlayer::load_sound_theme(const string &themefilename, Theme &theme)
   GError *error = NULL;
   gboolean r = TRUE;
   bool is_current = true;
-      
+
   GKeyFile *config = g_key_file_new();
 
   r = g_key_file_load_from_file(config, themefilename.c_str(), G_KEY_FILE_KEEP_COMMENTS, &error);
@@ -494,6 +515,7 @@ SoundPlayer::load_sound_theme(const string &themefilename, Theme &theme)
                   g_free(pathname);
                 }
             }
+          g_free(filename);
         }
 
       theme.active = is_current;
@@ -501,6 +523,8 @@ SoundPlayer::load_sound_theme(const string &themefilename, Theme &theme)
       
     }
 
+  g_key_file_free(config);
+    
   TRACE_MSG(is_current);
   TRACE_EXIT();
 }
@@ -590,6 +614,8 @@ SoundPlayer::play_sound(SoundEvent snd)
   TRACE_ENTER("SoundPlayer::play_sound");
   if (is_enabled())
     {
+      sync_settings();
+      
       bool enabled = false;
       bool valid = SoundPlayer::get_sound_enabled(snd, enabled);
 
