@@ -17,14 +17,15 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: KdeSoundPlayer.cc 1549 2008-06-28 21:51:43Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "debug.hh"
 
+#include <string>
+using namespace std;
+
 #include "KdeSoundPlayer.hh"
 #include <debug.hh>
 
@@ -46,7 +47,7 @@ KdeSoundPlayer::~KdeSoundPlayer()
 
 
 bool
-KdeSoundPlayer::capability(SounCapability cap)
+KdeSoundPlayer::capability(SoundPlayer::SoundCapability cap)
 {
   (void) cap;
   return false;
@@ -59,7 +60,7 @@ KdeSoundPlayer::play_sound(string wavfile)
 }
 
 void
-KdeSoundPlayer::play_sound(SoundEvent snd)
+KdeSoundPlayer::play_sound(SoundPlayer::SoundEvent snd)
 {
   const char *map[] = {
     "break_prelude",
@@ -80,3 +81,34 @@ KdeSoundPlayer::play_sound(SoundEvent snd)
   TRACE_EXIT();
 }
 
+
+bool
+KdeSoundPlayer::get_sound_enabled(SoundPlayer::SoundEvent snd, bool &enabled)
+{
+  (void) snd;
+  (void) enabled;
+  
+  return false;
+}
+
+void
+KdeSoundPlayer::set_sound_enabled(SoundPlayer::SoundEvent snd, bool enabled)
+{
+  (void) snd;
+  (void) enabled;
+}
+
+bool
+KdeSoundPlayer::get_sound_wav_file(SoundPlayer::SoundEvent snd, std::string &wav_file)
+{
+  (void) snd;
+  (void) wav_file;
+  return false;
+}
+
+void
+KdeSoundPlayer::set_sound_wav_file(SoundPlayer::SoundEvent snd, const std::string &wav_file)
+{
+  (void) snd;
+  (void) wav_file;
+}
