@@ -1,6 +1,6 @@
 // BreakWindow.cc --- base class for the break windows
 //
-// Copyright (C) 2001 - 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,23 +17,25 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: BreakWindow.cc 1524 2008-04-02 20:13:31Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include <ctime>
 
-// FIXME: Debug code, remove later
 #ifdef PLATFORM_OS_WIN32
-#include "w32debug.hh"
+#include "W32Compat.hh"
+#include <gdk/gdkwin32.h>
 #endif
 
 #include "preinclude.h"
 #include "debug.hh"
 #include "nls.h"
 
+#ifdef PLATFORM_OS_WIN32_NATIVE
+#undef max
+#endif
+
 #include <gtkmm/window.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/buttonbox.h>
@@ -43,6 +45,7 @@ static const char rcsid[] = "$Id: BreakWindow.cc 1524 2008-04-02 20:13:31Z rcael
 
 #include "GUI.hh"
 #include "BreakWindow.hh"
+#include "IBreak.hh"
 #include "IBreakResponse.hh"
 #include "GtkUtil.hh"
 #include "WindowHints.hh"
@@ -69,38 +72,47 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
                          BreakFlags break_flags,
                          GUIConfig::BlockMode mode) :
 #ifdef PLATFORM_OS_WIN32
-/*
- Windows will have a gtk toplevel window regardless of mode.
- Hopefully this takes care of the phantom parent problem.
- Also, the break window title now appears on the taskbar, and
- it will show up in Windows Task Manager's application list.
-*/
-         Gtk::Window( Gtk::WINDOW_TOPLEVEL ),
+  /*
+    Windows will have a gtk toplevel window regardless of mode.
+    Hopefully this takes care of the phantom parent problem.
+    Also, the break window title now appears on the taskbar, and
+    it will show up in Windows Task Manager's application list.
+  */
+  Gtk::Window( Gtk::WINDOW_TOPLEVEL ),
 #else
-         Gtk::Window(mode==GUIConfig::BLOCK_MODE_NONE
-                     ? Gtk::WINDOW_TOPLEVEL
-                     : Gtk::WINDOW_POPUP),
+  Gtk::Window(mode==GUIConfig::BLOCK_MODE_NONE
+              ? Gtk::WINDOW_TOPLEVEL
+              : Gtk::WINDOW_POPUP),
 #endif
-         block_mode(mode),
-         break_flags(break_flags),
-         frame(NULL),
-         break_response(NULL),
-         gui(NULL),
-         visible(false)
+  block_mode(mode),
+  break_flags(break_flags),
+  frame(NULL),
+  break_response(NULL),
+  gui(NULL),
+  visible(false)
 {
+  TRACE_ENTER("BreakWindow::BreakWindow");
   this->break_id = break_id;
 
 #ifdef PLATFORM_OS_WIN32
   desktop_window = NULL;
 
-  if (mode != GUIConfig::BLOCK_MODE_NONE)
-  {
-    // Disable titlebar to appear like a popup
-    set_decorated(false);
-    set_skip_taskbar_hint(true);
-  }
+  // Here's the secret: IMMEDIATELY after your window creation, set focus to it
+  // THEN position it. So:
+
+  HWND hwnd = (HWND) GDK_WINDOW_HWND(Gtk::Widget::gobj()->window);
+  ::SetFocus(hwnd);
+  ::SetWindowPos(hwnd, HWND_TOPMOST, 0, 0, 0, 0, SWP_NOMOVE|SWP_NOSIZE);
 #endif
 
+  if (mode != GUIConfig::BLOCK_MODE_NONE)
+    {
+      // Disable titlebar to appear like a popup
+      set_decorated(false);
+      set_skip_taskbar_hint(true);
+      set_skip_pager_hint(true);
+    }
+
   // On W32, must be *before* realize, otherwise a border is drawn.
   set_resizable(false);
 
@@ -122,38 +134,34 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
   HWND _hParent = GetAncestor( _hwnd, GA_PARENT );
   HWND _hDesktop = GetDesktopWindow();
   
-  APPEND_TIME( "BreakWindow created", hex << _hwnd );
-  
-  if( _hwnd != _scope )
+  TRACE_MSG("BreakWindow created" <<  hex << _hwnd);
+  if (_hwnd != _scope)
     {
-      APPEND( "!!!!!!!!!!!!!!!", "Scope issue: " << hex << _scope );
-      APPEND_ENDL();
-	}
+      TRACE_MSG("!!! Scope issue: " << hex << _scope);
+    }
   
-  if( _hwnd != _hRoot )
+  if (_hwnd != _hRoot)
     {
-	  APPEND( "GetDesktopWindow()", hex << _hDesktop );
-      APPEND( "!!!!!!!!!!!!!!!", "BreakWindow GA_ROOT: " << hex << _hRoot );
-      APPEND_ENDL();
-	}
+      TRACE_MSG("GetDesktopWindow()" <<  hex << _hDesktop);
+      TRACE_MSG("!!! BreakWindow GA_ROOT: " << hex << _hRoot);
+    }
   
-  if( _hParent != _hDesktop )
+  if (_hParent != _hDesktop)
     {
-	  APPEND( "GetDesktopWindow()", hex << _hDesktop );
-      APPEND( "!!!!!!!!!!!!!!!", "PreludeWindow GA_PARENT: " << hex << _hParent );
+      TRACE_MSG("GetDesktopWindow()" <<  hex << _hDesktop);
+      TRACE_MSG("!!! PreludeWindow GA_PARENT: " << hex << _hParent);
       
       HWND _hTemp;
       while( IsWindow( _hParent ) && _hParent != _hDesktop )
         {
-		  _hTemp = _hParent;
+          _hTemp = _hParent;
           _hParent = GetAncestor( _hTemp, GA_PARENT );
-		  HWND _hParent2 = (HWND)GetWindowLong( _hTemp, GWL_HWNDPARENT );
+          HWND _hParent2 = (HWND)GetWindowLong( _hTemp, GWL_HWNDPARENT );
           if( _hParent == _hTemp )
-              break;
-          APPEND( "!!!!!!!!!!!!!!!", hex << _hTemp << " GA_PARENT: " << hex << _hParent );
-          APPEND( "!!!!!!!!!!!!!!!", hex << _hTemp << " GWL_HWNDPARENT: " << hex << _hParent2 );
+            break;
+          TRACE_MSG("!!!" <<  hex << _hTemp << " GA_PARENT: " << hex << _hParent);
+          TRACE_MSG("!!!" <<  hex << _hTemp << " GWL_HWNDPARENT: " << hex << _hParent2);
         }
-      APPEND_ENDL();
     }
     
 #endif
@@ -167,11 +175,7 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
   bool initial_ignore_activity = false;
 
 #ifdef PLATFORM_OS_WIN32
-  bool force_focus = false;
-  CoreFactory::get_configurator()->get_value_with_default( "advanced/force_focus",
-                                                      force_focus,
-                                                      false);
-  if (force_focus)
+  if( W32Compat::get_force_focus_value() )
     {
       initial_ignore_activity = true;
     }
@@ -183,6 +187,7 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
   core->set_insist_policy(initial_ignore_activity ?
                           ICore::INSIST_POLICY_IGNORE :
                           ICore::INSIST_POLICY_HALT);
+  TRACE_EXIT();
 }
 
 
@@ -192,7 +197,7 @@ BreakWindow::init_gui()
 {
   if (gui == NULL)
     {
-      gui = manage(create_gui());
+      gui = Gtk::manage(create_gui());
 
       if (block_mode == GUIConfig::BLOCK_MODE_NONE)
         {
@@ -202,11 +207,11 @@ BreakWindow::init_gui()
       else
         {
           set_border_width(0);
-          Frame *window_frame = manage(new Frame());
+          Frame *window_frame = Gtk::manage(new Frame());
           window_frame->set_border_width(0);
           window_frame->set_frame_style(Frame::STYLE_BREAK_WINDOW);
 
-          frame = manage(new Frame());
+          frame = Gtk::manage(new Frame());
           frame->set_frame_style(Frame::STYLE_SOLID);
           frame->set_frame_width(6);
           frame->set_border_width(6);
@@ -227,7 +232,7 @@ BreakWindow::init_gui()
               set_app_paintable(true);
               set_desktop_background(GTK_WIDGET (gobj())->window);
               Gtk::Alignment *align
-                = manage(new Gtk::Alignment(0.5, 0.5, 0.0, 0.0));
+                = Gtk::manage(new Gtk::Alignment(0.5, 0.5, 0.0, 0.0));
               align->add(*window_frame);
               add(*align);
 #endif
@@ -284,7 +289,7 @@ BreakWindow::create_lock_button()
   Gtk::Button *ret;
   if (System::is_lockable())
     {
-      ret = manage(GtkUtil::create_image_button(_("Lock"), "lock.png"));
+      ret = Gtk::manage(GtkUtil::create_image_button(_("Lock"), "lock.png"));
       ret->signal_clicked()
         .connect(sigc::mem_fun(*this, &BreakWindow::on_lock_button_clicked));
       GTK_WIDGET_UNSET_FLAGS(ret->gobj(), GTK_CAN_FOCUS);
@@ -303,7 +308,7 @@ BreakWindow::create_shutdown_button()
   Gtk::Button *ret;
   if (System::is_shutdown_supported())
     {
-      ret = manage(GtkUtil::create_image_button(_("Shut down"), "shutdown.png"));
+      ret = Gtk::manage(GtkUtil::create_image_button(_("Shut down"), "shutdown.png"));
       ret->signal_clicked()
         .connect(sigc::mem_fun(*this, &BreakWindow::on_shutdown_button_clicked));
       GTK_WIDGET_UNSET_FLAGS(ret->gobj(), GTK_CAN_FOCUS);
@@ -320,7 +325,7 @@ Gtk::Button *
 BreakWindow::create_skip_button()
 {
   Gtk::Button *ret;
-  ret = manage(GtkUtil::create_custom_stock_button(_("Skip"), Gtk::Stock::CLOSE));
+  ret = Gtk::manage(GtkUtil::create_custom_stock_button(_("Skip"), Gtk::Stock::CLOSE));
   ret->signal_clicked()
     .connect(sigc::mem_fun(*this, &BreakWindow::on_skip_button_clicked));
   GTK_WIDGET_UNSET_FLAGS(ret->gobj(), GTK_CAN_FOCUS);
@@ -333,7 +338,7 @@ Gtk::Button *
 BreakWindow::create_postpone_button()
 {
   Gtk::Button *ret;
-  ret = manage(GtkUtil::create_custom_stock_button(_("Postpone"), Gtk::Stock::REDO));
+  ret = Gtk::manage(GtkUtil::create_custom_stock_button(_("Postpone"), Gtk::Stock::REDO));
   ret->signal_clicked()
     .connect(sigc::mem_fun(*this, &BreakWindow::on_postpone_button_clicked));
   GTK_WIDGET_UNSET_FLAGS(ret->gobj(), GTK_CAN_FOCUS);
@@ -373,7 +378,10 @@ BreakWindow::on_shutdown_button_clicked()
 bool
 BreakWindow::on_delete_event(GdkEventAny *)
 {
-  on_postpone_button_clicked();
+  if (block_mode == GUIConfig::BLOCK_MODE_NONE)
+    {
+      on_postpone_button_clicked();
+    }
   return TRUE;
 }
 
@@ -394,6 +402,7 @@ BreakWindow::on_postpone_button_clicked()
   if (break_response != NULL)
     {
       break_response->postpone_break(break_id);
+      resume_non_ignorable_break();
     }
   TRACE_EXIT();
 }
@@ -407,10 +416,40 @@ BreakWindow::on_skip_button_clicked()
   if (break_response != NULL)
     {
       break_response->skip_break(break_id);
+      resume_non_ignorable_break();
     }
 }
 
 
+void
+BreakWindow::resume_non_ignorable_break()
+{
+  TRACE_ENTER("BreakWindow::resume_non_ignorable_break");
+  for (int id = break_id - 1; id >= 0; id--)
+    {
+      TRACE_MSG("Break " << id << ": check ignorable");
+
+      bool ignorable = GUIConfig::get_ignorable(BreakId(id));
+      if (!ignorable)
+        {
+          TRACE_MSG("Break " << id << " not ignorable");
+          
+          ICore *core = CoreFactory::get_core();
+          assert(core != NULL);
+              
+          IBreak *b = core->get_break(BreakId(id));
+          assert(b != NULL);
+
+          if (b->get_elapsed_time() > b->get_limit())
+            {
+              TRACE_MSG("Break " << id << " not ignorable and overdue");
+
+              core->force_break(BreakId(id), false);
+              break;
+            }
+        }
+    }
+}
 
 //! Control buttons.
 Gtk::HButtonBox *
@@ -429,7 +468,7 @@ BreakWindow::create_break_buttons(bool lockable,
           shutdown_button = create_shutdown_button();
           if (shutdown_button != NULL)
             {
-              box->pack_end(*shutdown_button, Gtk::SHRINK, 0);
+				box->pack_end(*shutdown_button, Gtk::PACK_SHRINK, 0);
             }
         }
 
@@ -438,20 +477,20 @@ BreakWindow::create_break_buttons(bool lockable,
           Gtk::Button *lock_button = create_lock_button();
           if (lock_button != NULL)
             {
-              box->pack_end(*lock_button, Gtk::SHRINK, 0);
+              box->pack_end(*lock_button, Gtk::PACK_SHRINK, 0);
             }
         }
 
       if ((break_flags & BREAK_FLAGS_SKIPPABLE) != 0)
         {
           Gtk::Button *skip_button = create_skip_button();
-          box->pack_end(*skip_button, Gtk::SHRINK, 0);
+          box->pack_end(*skip_button, Gtk::PACK_SHRINK, 0);
         }
       
         if ((break_flags & BREAK_FLAGS_POSTPONABLE) != 0)
         {
           Gtk::Button *postpone_button = create_postpone_button();
-          box->pack_end(*postpone_button, Gtk::SHRINK, 0);
+          box->pack_end(*postpone_button, Gtk::PACK_SHRINK, 0);
         }
     }
 
@@ -486,18 +525,6 @@ BreakWindow::start()
   // Set window hints.
   set_skip_pager_hint(true);
   set_skip_taskbar_hint(true);
-
-#ifdef PLATFORM_OS_WIN32
-  // FIXME: hack until gtk+ is fixed.
-  GtkWidget *gtkwin = Gtk::Widget::gobj();
-  GdkWindow *gdkwin = gtkwin->window;
-
-  parent = GetWindowLong((HWND)GDK_WINDOW_HWND(gdkwin), GWL_HWNDPARENT);
-    
-  SetWindowLong((HWND)GDK_WINDOW_HWND(gdkwin), GWL_HWNDPARENT,
-                (long) GetDesktopWindow());
-#endif
-  
   WindowHints::set_always_on_top(this, true);
   raise();
 
@@ -512,13 +539,6 @@ BreakWindow::stop()
 {
   TRACE_ENTER("BreakWindow::stop");
 
-#ifdef PLATFORM_OS_WIN32
-  GtkWidget *gtkwin = Gtk::Widget::gobj();
-  GdkWindow *gdkwin = gtkwin->window;
-  SetWindowLong((HWND)GDK_WINDOW_HWND(gdkwin), GWL_HWNDPARENT,
-                parent);
-#endif
-  
   if (frame != NULL)
     {
       frame->set_frame_flashing(0);
@@ -554,12 +574,12 @@ BreakWindow::refresh()
 {
   update_break_window();
   
-// #ifdef PLATFORM_OS_WIN32
-//   if (block_mode != GUIConfig::BLOCK_MODE_NONE)
-//     {
-//       WindowHints::set_always_on_top(this, true);
-//     }
-// #endif
+ #ifdef PLATFORM_OS_WIN32
+   if (block_mode != GUIConfig::BLOCK_MODE_NONE)
+     {
+       WindowHints::set_always_on_top(this, true);
+     }
+ #endif
 }
 
 Glib::RefPtr<Gdk::Window>
