@@ -1,6 +1,6 @@
 // GUI.cc --- The WorkRave GUI
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: GUI.cc 1549 2008-06-28 21:51:43Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -27,15 +25,14 @@ static const char rcsid[] = "$Id: GUI.cc 1549 2008-06-28 21:51:43Z rcaelers $";
 #include "nls.h"
 #include "debug.hh"
 
-#if defined(PLATFORM_OS_WIN32)
-#include "w32debug.hh"
-#endif
-
 #include <gtkmm/main.h>
 #include <gtkmm/messagedialog.h>
+#include <glibmm/optiongroup.h>
 #include <glibmm/refptr.h>
 
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <stdio.h>
 #include <assert.h>
 #include <fcntl.h>
@@ -49,7 +46,8 @@ static const char rcsid[] = "$Id: GUI.cc 1549 2008-06-28 21:51:43Z rcaelers $";
 #include "IConfigurator.hh"
 #include "ICore.hh"
 #include "CoreFactory.hh"
-  
+
+#include "Exception.hh"
 #include "AppletControl.hh"
 #include "AppletWindow.hh"
 #include "BreakWindow.hh"
@@ -88,16 +86,15 @@ static const char rcsid[] = "$Id: GUI.cc 1549 2008-06-28 21:51:43Z rcaelers $";
 #include <gconf/gconf-client.h>
 #endif
 
-#if defined(HAVE_GNOMEMM)
-#include "libgnomeuimm/wrap_init.h"
-#endif
-
 #if defined(HAVE_KDE)
 #include <dcopclient.h>
 #include <kapp.h>
 #endif
 
 #if defined(HAVE_DBUS)
+#if defined(PLATFORM_OS_WIN32_NATIVE)
+#undef interface
+#endif
 #include "DBus.hh"
 #include "DBusException.hh"
 #endif
@@ -188,19 +185,29 @@ GUI::main()
 {
   TRACE_ENTER("GUI::main");
 
-#if defined (PLATFORM_OS_WIN32) || defined(PLATFORM_OS_OSX)
-  // Win32/OSX need this....
-  if (!g_thread_supported())
-    {
-      g_thread_init(NULL);
-    }
-#endif
-  
-  Gtk::Main kit(argc, argv);
+  Glib::OptionContext option_ctx;
 
+  if (!Glib::thread_supported())
+    Glib::thread_init();
+#ifdef HAVE_DBUS
+  Glib::OptionGroup *option_group = new Glib::OptionGroup(egg_sm_client_get_option_group());
+  option_ctx.add_group(*option_group);
+#endif
+  Gtk::Main *kit = NULL;
+  try
+    {
+      kit = new Gtk::Main(argc, argv, option_ctx);
+    }
+  catch (const Glib::OptionError &e)
+    {
+      std::cout << "Failed to initialize: " << e.what() << std::endl;
+      exit(1);
+    }
+  
   init_core();
   init_nls();
   init_platform();
+  init_session();
   init_debug();
   init_sound_player();
   init_multihead();
@@ -209,22 +216,24 @@ GUI::main()
   
   on_timer();
 
-#if defined(PLATFORM_OS_WIN32)
-  // FIXME: debug, remove later
-  APPEND_TIME( "Workrave started and initialized", "Entering event loop." );
-#endif
+  TRACE_MSG("Initialized. Entering event loop.");
 
   // Enter the event loop
   gdk_threads_enter();
   Gtk::Main::run();
   gdk_threads_leave();
 
+  cleanup_session();
+    
   delete main_window;
   main_window = NULL;
 
   delete applet_control;
   applet_control = NULL;
 
+  delete kit;
+
+  
   TRACE_EXIT();
 }
 
@@ -318,9 +327,6 @@ static void my_log_handler(const gchar *log_domain, GLogLevelFlags log_level,
 void
 GUI::init_platform()
 {
-#if defined(HAVE_GNOME)
-  init_gnome();
-#endif
 #if defined(HAVE_KDE)
   init_kde();
 #endif
@@ -328,14 +334,6 @@ GUI::init_platform()
   [ [ AppController alloc ] init ];
 #endif
   
-#if defined (PLATFORM_OS_WIN32) || defined(PLATFORM_OS_OSX)
-  // Win32/OSX need this....
-  if (!g_thread_supported())
-    {
-      g_thread_init(NULL);
-    }
-#endif
-
 #if defined(PLATFORM_OS_UNIX)
   char *display = gdk_get_display();
   System::init(display);
@@ -344,36 +342,17 @@ GUI::init_platform()
   System::init();
 #endif
   
-  srand(time(NULL));
+  srand((unsigned int)time(NULL));
 }
 
 
-#if defined(HAVE_GNOME)
 void
-GUI::init_gnome()
+GUI::session_quit_cb(EggSMClient *client, GUI *gui)
 {
-  TRACE_ENTER("GUI::init_gnome");
-
-  gnome_init("workrave", VERSION, argc, argv);
-#if defined(HAVE_GNOMEMM)
-  Gnome::UI::wrap_init();
-
-  Gnome::UI::Client *client = Gnome::UI::Client::master_client();
-  if (client != NULL)
-    {
-      client->signal_save_yourself().connect(sigc::mem_fun(*this, &GUI::on_save_yourself));
-      client->signal_die().connect(sigc::mem_fun(*this, &GUI::on_die));
-    }
-
-  TRACE_EXIT();
-#endif
-}
-
-#if defined(HAVE_GNOMEMM)
-void
-GUI::on_die()
-{
-  TRACE_ENTER("GUI::on_die");
+  (void) client;
+  (void) gui;
+  
+  TRACE_ENTER("GUI::session_quit_cb");
 
   CoreFactory::get_configurator()->save();
   Gtk::Main::quit();
@@ -382,65 +361,61 @@ GUI::on_die()
 }
 
 
-bool
-GUI::on_save_yourself(int phase, Gnome::UI::SaveStyle save_style, bool shutdown,
-                      Gnome::UI::InteractStyle interact_style, bool fast)
+void
+GUI::session_save_state_cb(EggSMClient *client, GKeyFile *key_file, GUI *gui)
 {
-  TRACE_ENTER("GUI::on_save_yourself");
-
-  (void) phase;
-  (void) save_style;
-  (void) shutdown;
-  (void) interact_style;
-  (void) fast;
-
-  Gnome::UI::Client *client = Gnome::UI::Client::master_client();
-
-  vector<string> args;
-  args.push_back(argv[0] != NULL ? argv[0] : "workrave");
-
-  bool skip = false;
-
-  if (applet_control != NULL)
+  (void) client;
+  (void) key_file;
+  (void) gui;
+  
+  CoreFactory::get_configurator()->save();
+}
+
+void
+GUI::init_session()
+{
+  EggSMClient *client = NULL;
+#ifdef HAVE_DBUS
+  client = egg_sm_client_get();
+#endif
+  if (client)
     {
-      if (applet_control->is_visible(AppletControl::APPLET_GNOME))
-        {
-          skip = true;
-        }
+      g_signal_connect(client,
+                       "quit",
+                       G_CALLBACK(session_quit_cb),
+                       this);
+      g_signal_connect(client,
+                       "save-state",
+                       G_CALLBACK(session_save_state_cb),
+                       this);
     }
+}
+
 
-  if (skip)
+void
+GUI::cleanup_session()
+{
+  EggSMClient *client = NULL;
+#ifdef HAVE_DBUS
+  client = egg_sm_client_get();
+#endif
+  if (client)
     {
-      client->set_restart_style(GNOME_RESTART_NEVER);
+      g_signal_handlers_disconnect_by_func(client,
+                                           (gpointer)G_CALLBACK(session_quit_cb),
+                                           this);
+      g_signal_handlers_disconnect_by_func(client,
+                                           (gpointer)G_CALLBACK(session_save_state_cb),
+                                           this);
     }
-  else
-    {
-      client->set_restart_style(GNOME_RESTART_IF_RUNNING);
-
-      char *display_name = gdk_get_display();
-      if (display_name != NULL)
-        {
-          args.push_back("--display");
-          args.push_back(display_name);
-        }
-    }
-
-  client->set_clone_command(args);
-  client->set_restart_command(args);
-
-  TRACE_EXIT();
-  return true;
 }
 
-#endif // defined HAVE_GNOMEMM
-#endif // defined HAVE_GNOME
 
 
 #if defined(HAVE_KDE)
 void
 GUI::init_kde()
 {
-  // FIXME: memory leaks in here.
   TRACE_ENTER("GUI::init_kde");
   new KApplication(argc, argv, "Workrave");
   bool rc = kapp->dcopClient()->attach();
@@ -777,7 +752,7 @@ GUI::init_gtk_multihead()
 void
 GUI::init_gui()
 {
-  tooltips = manage(new Gtk::Tooltips());
+  tooltips = Gtk::manage(new Gtk::Tooltips());
   tooltips->enable();
 
   menus = new Menus();
@@ -850,7 +825,7 @@ GUI::init_dbus()
           extern void init_DBusGUI(DBus *dbus);
           init_DBusGUI(dbus);
         }
-      catch (DBusException &e)
+      catch (DBusException &)
         {
         }
     }  
@@ -885,7 +860,17 @@ GUI::create_break_window(HeadInfo &head, BreakId break_id, BreakWindow::BreakFla
 void
 GUI::init_sound_player()
 {
-  sound_player = new SoundPlayer(); /* LEAK */
+  TRACE_ENTER("GUI:init_sound_player");
+  try
+    {
+      sound_player = new SoundPlayer(); /* LEAK */
+      sound_player->init();
+    }
+  catch (Exception)
+    {
+      TRACE_MSG("No sound");
+    }
+  TRACE_EXIT();
 }
 
 
@@ -911,6 +896,8 @@ GUI::core_event_operation_mode_changed(const OperationMode m)
       status_icon->set_operation_mode(m);
     }
 
+  
+  
   menus->resync();
 }
 
@@ -991,10 +978,6 @@ GUI::create_break_window(BreakId break_id, bool user_initiated)
     }
 
   active_break_count = num_heads;
-  if (GUIConfig::get_block_mode() != GUIConfig::BLOCK_MODE_NONE)
-    {
-      grab();
-    }
 
   TRACE_EXIT();
 }
@@ -1056,6 +1039,11 @@ GUI::show_break_window()
         }
     }
 
+  if (GUIConfig::get_block_mode() != GUIConfig::BLOCK_MODE_NONE)
+    {
+      grab();
+    }
+  
   TRACE_EXIT();
 }
 
@@ -1177,8 +1165,11 @@ GUI::grab()
 {
   if (break_windows != NULL && active_break_count > 0)
     {
-      GdkWindow *windows[active_break_count];
-
+#ifdef PLATFORM_OS_WIN32_NATIVE
+		GdkWindow *windows[BREAK_ID_SIZEOF];
+#else
+	  GdkWindow *windows[active_break_count];
+#endif
       for (int i = 0; i < active_break_count; i++)
         {
           Glib::RefPtr<Gdk::Window> window = break_windows[i]->get_gdk_window();
@@ -1381,10 +1372,30 @@ std::string
 GUI::get_timers_tooltip()
 {
   //FIXME: duplicate
-  char *labels[] = { _("Micro-break"), _("Rest break"), _("Daily limit") };
+  const char *labels[] = { _("Micro-break"), _("Rest break"), _("Daily limit") };
   string tip = "";
 
   ICore *core = CoreFactory::get_core();
+
+  OperationMode mode = core->get_operation_mode();
+  switch (mode)
+    {
+    case OPERATION_MODE_NORMAL:
+      tip = "Workrave";
+      break;
+        
+    case OPERATION_MODE_SUSPENDED:
+      tip = string(_("Mode: ")) +   _("Suspended");
+      break;
+
+    case OPERATION_MODE_QUIET:
+      tip = string(_("Mode: ")) +   _("Quiet");
+      break;
+
+    default:
+      break;
+    }
+  
   for (int count = 0; count < BREAK_ID_SIZEOF; count++)
     {
       IBreak *b = core->get_break(BreakId(count));
@@ -1428,11 +1439,24 @@ GUI::get_timers_tooltip()
 }
 
 
+bool
+GUI::is_status_icon_visible() const
+{
+  bool ret = false;
+
+  if (status_icon != NULL)
+    {
+      ret = status_icon->is_embedded();
+    }
+
+  return ret;
+}
+
 #if defined(PLATFORM_OS_WIN32)
 void
 GUI::win32_init_filter()
 {
-  GtkWidget *window = main_window->Gtk::Widget::gobj();
+  GtkWidget *window = (GtkWidget *)main_window->gobj();
   GdkWindow *gdk_window = window->window;
   gdk_window_add_filter(gdk_window, win32_filter_func, this);
 }
@@ -1454,74 +1478,38 @@ GUI::win32_filter_func (void     *xevent,
       {
         TRACE_MSG("WM_POWERBROADCAST " << msg->wParam << " " << msg->lParam);
 
-#if defined(PLATFORM_OS_WIN32)
-// FIXME: debug, remove later
-switch (msg->wParam)
-{
-case PBT_APMBATTERYLOW:
-APPEND_TIME("WM_POWERBROADCAST", "PBT_APMBATTERYLOW");
-break;
-case PBT_APMOEMEVENT:
-APPEND_TIME("WM_POWERBROADCAST", "PBT_APMOEMEVENT");
-break;
-case PBT_APMPOWERSTATUSCHANGE:
-APPEND_TIME("WM_POWERBROADCAST", "PBT_APMPOWERSTATUSCHANGE");
-break;
-case PBT_APMQUERYSUSPEND:
-APPEND_TIME("WM_POWERBROADCAST", "PBT_APMQUERYSUSPEND");
-break;
-case PBT_APMQUERYSUSPENDFAILED:
-APPEND_TIME("WM_POWERBROADCAST", "PBT_APMQUERYSUSPENDFAILED");
-break;
-case PBT_APMRESUMEAUTOMATIC:
-APPEND_TIME("WM_POWERBROADCAST", "PBT_APMRESUMEAUTOMATIC");
-break;
-case PBT_APMRESUMECRITICAL:
-APPEND_TIME("WM_POWERBROADCAST", "PBT_APMRESUMECRITICAL");
-break;
-case PBT_APMRESUMESUSPEND:
-APPEND_TIME("WM_POWERBROADCAST", "PBT_APMRESUMESUSPEND");
-break;
-case PBT_APMSUSPEND:
-APPEND_TIME("WM_POWERBROADCAST", "PBT_APMSUSPEND");
-break;
-default:
-APPEND_TIME("WM_POWERBROADCAST", "<UNKNOWN MESSAGE> : " << hex << msg->wParam );
-}
-#endif
+        switch (msg->wParam)
+          {
+          case PBT_APMQUERYSUSPEND:
+            TRACE_MSG("Query Suspend");
+            break;
 
-          switch (msg->wParam)
+          case PBT_APMQUERYSUSPENDFAILED:
+            TRACE_MSG("Query Suspend Failed");
+            break;
+
+          case PBT_APMRESUMESUSPEND:
             {
-            case PBT_APMQUERYSUSPEND:
-              TRACE_MSG("Query Suspend");
-              break;
-
-            case PBT_APMQUERYSUSPENDFAILED:
-              TRACE_MSG("Query Suspend Failed");
-              break;
-
-            case PBT_APMRESUMESUSPEND:
-              {
-                TRACE_MSG("Resume suspend");
-                ICore *core = CoreFactory::get_core();
-                if (core != NULL)
-                  {
-                    core->set_powersave(false);
-                  }
-              }
-              break;
-
-            case PBT_APMSUSPEND:
-              {
-                TRACE_MSG("Suspend");
-                ICore *core = CoreFactory::get_core();
-                if (core != NULL)
-                  {
-                    core->set_powersave(true);
-                  }
-              }
-              break;
+              TRACE_MSG("Resume suspend");
+              ICore *core = CoreFactory::get_core();
+              if (core != NULL)
+                {
+                  core->set_powersave(false);
+                }
             }
+            break;
+
+          case PBT_APMSUSPEND:
+            {
+              TRACE_MSG("Suspend");
+              ICore *core = CoreFactory::get_core();
+              if (core != NULL)
+                {
+                  core->set_powersave(true);
+                }
+            }
+            break;
+          }
       }
       break;
 
