@@ -17,7 +17,7 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: GnomeAppletWindow.cc 1513 2008-03-26 18:16:44Z rcaelers $";
+using namespace std;
 
 #include "preinclude.h"
 
@@ -111,10 +111,14 @@ GnomeAppletWindow::activate_applet()
               applet_orientation =  (Orientation) applet_control->GetOrientation();
 
 #ifndef HAVE_EXERCISES
-              applet_control->SetMenuActive("/commands/Exercises", false);
+              const std::string exercices_command("/commands/Exercises");
+              bool exercices_command_status(false);
+              applet_control->SetMenuActive(exercices_command, exercices_command_status);
 #endif
 #ifndef HAVE_DISTRIBUTION
-              applet_control->SetMenuActive("/commands/Network", false);
+              const std::string network_command("/commands/Network");
+              bool network_command_status(false);
+              applet_control->SetMenuActive(network_command, network_command_status);
 #endif
             }
         }
