@@ -1,18 +1,21 @@
 // IconListCellRenderer.cc --- Icon list cell renderer
 //
-// Copyright (C) 2001, 2002, 2003 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
-// This program is free software; you can redistribute it and/or modify
+// This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2, or (at your option)
-// any later version.
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+//
 
 #include <gtk/gtkcellrenderer.h>
 #include <gtkmm/cellrenderer.h>
@@ -109,11 +112,7 @@ IconListCellRenderer::get_size_vfunc(Gtk::Widget& widget,
 
 void
 IconListCellRenderer::render_vfunc(
-#ifdef HAVE_GTKMM24
                                    const Glib::RefPtr<Gdk::Drawable>& window,
-#else
-                                   const Glib::RefPtr<Gdk::Window>& window,
-#endif
                                    Gtk::Widget& widget,
                                    const Gdk::Rectangle& bg_area,
                                    const Gdk::Rectangle& cell_area,
