@@ -16,8 +16,6 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Id: IconListNotebook.cc 1351 2007-10-14 20:56:54Z rcaelers $
-//
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -40,7 +38,7 @@ IconListNotebook::IconListNotebook()
 {
   icon_list.show();
   icon_list.set_headers_visible(false);
-  Gtk::ScrolledWindow *scroller = manage(new Gtk::ScrolledWindow());
+  Gtk::ScrolledWindow *scroller = Gtk::manage(new Gtk::ScrolledWindow());
   scroller->set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_ALWAYS);
   scroller->set_shadow_type(Gtk::SHADOW_IN);
   scroller->show();
