@@ -1,6 +1,6 @@
 // MainWindow.cc --- Main info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: MainWindow.cc 1537 2008-06-08 19:02:40Z rcaelers $";
-
 #include "preinclude.h"
 
 #ifdef HAVE_CONFIG_H
@@ -33,13 +31,12 @@ static const char rcsid[] = "$Id: MainWindow.cc 1537 2008-06-08 19:02:40Z rcaele
 #include "nls.h"
 #include "debug.hh"
 
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#include <iostream>
-
-#ifdef HAVE_GNOME
-#include <gnome.h>
 #endif
 
+#include <iostream>
+
 #include "AppletControl.hh"
 
 #include "TimerBoxGtkView.hh"
@@ -154,7 +151,7 @@ MainWindow::init()
 
   enabled = TimerBoxControl::is_enabled("main_window");
 
-  timer_box_view = manage(new TimerBoxGtkView(Menus::MENU_MAINWINDOW));
+  timer_box_view = Gtk::manage(new TimerBoxGtkView(Menus::MENU_MAINWINDOW));
   timer_box_control = new TimerBoxControl("main_window", *timer_box_view);
   timer_box_view->set_geometry(ORIENTATION_LEFT, -1);
   timer_box_control->update();
@@ -194,7 +191,7 @@ MainWindow::init()
   set_gravity(Gdk::GRAVITY_STATIC);
   set_position(Gtk::WIN_POS_NONE);
 
-#ifndef HAVE_NOT_PROPER_SIZED_MAIN_WINDOW_ON_STARTUP
+#ifdef HAVE_NOT_PROPER_SIZED_MAIN_WINDOW_ON_STARTUP
   // This is the proper code, see hacked code below.
   if (!enabled)
     {
@@ -205,7 +202,7 @@ MainWindow::init()
     }
   else
     {
-      move_to_start_position();;
+      move_to_start_position();
       show_all();
     }
 #else // Hack deprecated: Since GTK+ 2.10 no longer necessary
@@ -234,7 +231,9 @@ MainWindow::init()
 
   if (!enabled) //  || get_start_in_tray())
     {
+#ifndef PLATFORM_OS_OSX
       iconify();
+#endif
       close_window();
     }
 #endif
@@ -335,6 +334,8 @@ MainWindow::open_window()
 
       bool always_on_top = get_always_on_top();
       WindowHints::set_always_on_top(this, always_on_top);
+
+      TimerBoxControl::set_enabled("main_window", true);
     }
   TRACE_EXIT();
 }
@@ -350,7 +351,8 @@ MainWindow::close_window()
 #elif defined(PLATFORM_OS_OSX)
   hide_all();
 #else
-  if (applet_active)
+  GUI *gui = GUI::get_instance();
+  if (applet_active || gui->is_status_icon_visible())
     {
       hide_all();
     }
@@ -379,7 +381,8 @@ MainWindow::on_delete_event(GdkEventAny *)
   AppletControl *applet_control = gui->get_applet_control();
   if (applet_control != NULL)
     {
-      terminate = !applet_control->is_visible();
+      terminate = ( !applet_control->is_visible() &&
+                    !gui->is_status_icon_visible() );
     }
 
   if (terminate)
@@ -491,36 +494,20 @@ MainWindow::win32_show(bool b)
   HWND hwnd = (HWND) GDK_WINDOW_HWND(gdk_window);
   ShowWindow(hwnd, b ? SW_SHOWNORMAL : SW_HIDE);
 
-  if( b )
-    // jay satiro, workrave project, june 2007
-    // redistribute under GNU terms.
-    {
-      SetWindowPos( hwnd, 0, 0, 0, 0, 0,
-                    SWP_NOMOVE | SWP_NOSIZE | SWP_NOZORDER | SWP_SHOWWINDOW );
-      {
-        HWND hFore = GetForegroundWindow();
-        DWORD dThisThread, dForeThread, dForePID;
-  
-        dThisThread = GetCurrentThreadId();
-        dForeThread = GetWindowThreadProcessId( hFore, &dForePID );
-    
-        AttachThreadInput( dThisThread, dForeThread, TRUE );
-        /**/
-        present();
-        /**/
-        hFore = GetForegroundWindow();
-        if( hwnd != hFore )
-          {
-            BringWindowToTop( hwnd );
-            SetForegroundWindow( hwnd );
-          }
-        AttachThreadInput( dThisThread, dForeThread, FALSE );
-      }
-    }
-  else
-    {
-      ShowWindow( hwnd, SW_HIDE );
-    }
+	if( b )
+	// show main window
+	{
+		/**/
+		present(); //works in all my testing. does this not always work?
+		/**/
+		if( hwnd != GetForegroundWindow() )
+		{
+			SetWindowPos( hwnd, HWND_TOP, 0, 0, 0, 0, 
+				SWP_NOMOVE | SWP_NOSIZE | SWP_FRAMECHANGED | SWP_SHOWWINDOW );
+			//BringWindowToTop( hwnd );
+			SetForegroundWindow( hwnd );
+		}
+	}
 }
 
 
@@ -651,7 +638,8 @@ MainWindow::set_applet_active(bool a)
 
   if (!enabled)
     {
-      if (applet_active)
+      GUI *gui = GUI::get_instance();
+      if (applet_active || gui->is_status_icon_visible())
         {
           hide_all();
         }
@@ -666,6 +654,26 @@ MainWindow::set_applet_active(bool a)
 }
 
 
+void
+MainWindow::status_icon_changed()
+{
+  TRACE_ENTER("MainWindow::status_icon_changed");
+  if (!enabled)
+    {
+      GUI *gui = GUI::get_instance();
+      if (applet_active || gui->is_status_icon_visible())
+        {
+          hide_all();
+        }
+      else
+        {
+          iconify();
+          show_all();
+        }
+    }
+  TRACE_EXIT();
+}
+
 bool
 MainWindow::on_configure_event(GdkEventConfigure *event)
 {
@@ -686,6 +694,14 @@ MainWindow::locate_window(GdkEventConfigure *event)
 
   (void) event;
 
+  Glib::RefPtr<Gdk::Window> window = get_window();
+  TRACE_MSG(window->get_state());
+  if ((window->get_state() & (Gdk::WINDOW_STATE_ICONIFIED | Gdk::WINDOW_STATE_WITHDRAWN)) != 0)
+    {
+      TRACE_EXIT();
+      return;
+    }
+  
 #ifndef PLATFORM_OS_WIN32
   // Returns bogus results on windows...sometime.
   if (event != NULL)
