@@ -1,6 +1,6 @@
 // Menus.cc --- Timer info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: Menus.cc 1578 2008-07-11 19:32:10Z rcaelers $";
-
 #include "preinclude.h"
 
 #ifdef HAVE_CONFIG_H
@@ -29,7 +27,9 @@ static const char rcsid[] = "$Id: Menus.cc 1578 2008-07-11 19:32:10Z rcaelers $"
 #include "debug.hh"
 #include "credits.h"
 
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <iostream>
 
 #include <gtkmm/aboutdialog.h>
@@ -347,7 +347,7 @@ Menus::on_menu_about()
       about->set_logo(pixbuf);
       about->set_translator_credits(workrave_translators);
 
-      about->set_version(VERSION);
+      about->set_version(PACKAGE_VERSION);
       about->set_website("http://www.workrave.org/");
       about->set_website_label("www.workrave.org");
 
@@ -462,6 +462,7 @@ Menus::on_menu_network_log(bool active)
 }
 
 
+#ifdef HAVE_DISTRIBUTION
 void
 Menus::on_network_log_response(int response)
 {
@@ -476,6 +477,7 @@ Menus::on_network_log_response(int response)
   // done by gtkmm ??? delete network_log_dialog;
   network_log_dialog = NULL;
 }
+#endif
 
 void
 Menus::on_statistics_response(int response)
@@ -489,7 +491,6 @@ Menus::on_statistics_response(int response)
   statistics_dialog = NULL;
 }
 
-
 void
 Menus::on_preferences_response(int response)
 {
@@ -512,9 +513,11 @@ Menus::applet_command(short cmd)
     case MENU_COMMAND_PREFERENCES:
       on_menu_preferences();
       break;
+#ifdef HAVE_EXERCISES
     case MENU_COMMAND_EXERCISES:
       on_menu_exercises();
       break;
+#endif
     case MENU_COMMAND_REST_BREAK:
       on_menu_restbreak_now();
       break;
@@ -533,13 +536,15 @@ Menus::applet_command(short cmd)
     case MENU_COMMAND_NETWORK_DISCONNECT:
       on_menu_network_leave();
       break;
+#ifdef HAVE_DISTRIBUTION
     case MENU_COMMAND_NETWORK_LOG:
       on_menu_network_log(network_log_dialog == NULL);
       break;
     case MENU_COMMAND_NETWORK_RECONNECT:
       on_menu_network_reconnect();
       break;
-    case MENU_COMMAND_STATISTICS:
+#endif
+	case MENU_COMMAND_STATISTICS:
       on_menu_statistics();
       break;
     case MENU_COMMAND_ABOUT:
@@ -565,7 +570,12 @@ Menus::resync()
           ICore *core = CoreFactory::get_core();
 
           menus[i]->resync(core->get_operation_mode(),
+#ifdef HAVE_DISTRIBUTION
                            network_log_dialog != NULL);
+#else
+                           false);
+#endif
+
         }
     }
 
