@@ -1,6 +1,6 @@
 // PreludeWindow.cc
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: PreludeWindow.cc 1540 2008-06-18 20:12:19Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -30,9 +28,6 @@ static const char rcsid[] = "$Id: PreludeWindow.cc 1540 2008-06-18 20:12:19Z rca
 #include <gtkmm/box.h>
 
 #include "debug.hh"
-#if defined(PLATFORM_OS_WIN32)
-#include "w32debug.hh"
-#endif
 #include "nls.h"
 
 #include "Text.hh"
@@ -70,32 +65,33 @@ PreludeWindow::PreludeWindow(HeadInfo &head, BreakId break_id)
     flash_visible(false),
     prelude_response(NULL)
 {
+  TRACE_ENTER("PreludeWindow::PreludeWindow");
   Gtk::Window::set_border_width(0);
 
   init_avoid_pointer();
   realize();
 
   // Time bar
-  time_bar = manage(new TimeBar);
+  time_bar = Gtk::manage(new TimeBar);
 
   // Label
-  label = manage(new Gtk::Label());
+  label = Gtk::manage(new Gtk::Label());
 
   // Box
-  Gtk::VBox *vbox = manage(new Gtk::VBox(false, 6));
+  Gtk::VBox *vbox = Gtk::manage(new Gtk::VBox(false, 6));
   vbox->pack_start(*label, false, false, 0);
   vbox->pack_start(*time_bar, false, false, 0);
 
   // Icon
-  image_icon = manage(new Gtk::Image());
+  image_icon = Gtk::manage(new Gtk::Image());
 
   // Box
-  Gtk::HBox *hbox = manage(new Gtk::HBox(false, 6));
+  Gtk::HBox *hbox = Gtk::manage(new Gtk::HBox(false, 6));
   hbox->pack_start(*image_icon, false, false, 0);
   hbox->pack_start(*vbox, false, false, 0);
 
   // Frame
-  frame = manage(new Frame);
+  frame = Gtk::manage(new Frame);
   frame->set_frame_style(Frame::STYLE_SOLID);
   frame->set_frame_width(6);
   frame->set_border_width(6);
@@ -136,28 +132,25 @@ PreludeWindow::PreludeWindow(HeadInfo &head, BreakId break_id)
   HWND _scope = (HWND) GDK_WINDOW_HWND( GTK_WIDGET( this->gobj() )->window );
   HWND _hRoot = GetAncestor( _hwnd, GA_ROOT );
   HWND _hParent = GetAncestor( _hwnd, GA_PARENT );
-  //HWND _hParent2 = (HWND)GetWindowLong( _hwnd, GWL_HWNDPARENT );
   HWND _hDesktop = GetDesktopWindow();
   
-  APPEND_TIME( "PreludeWindow created", hex << _hwnd );
+  TRACE_MSG("PreludeWindow created" <<  hex << _hwnd);
   
-  if( _hwnd != _scope )
+  if (_hwnd != _scope)
     {
-      APPEND( "!!!!!!!!!!!!!!!", "Scope issue: " << hex << _scope );
-      APPEND_ENDL();
+      TRACE_MSG( "!!!!!!!!!!!!!!!" <<  "Scope issue: " << hex << _scope );
     }
   
-  if( _hwnd != _hRoot )
+  if (_hwnd != _hRoot)
     {
-      APPEND( "GetDesktopWindow()", hex << _hDesktop );
-      APPEND( "!!!!!!!!!!!!!!!", "PreludeWindow GA_ROOT: " << hex << _hRoot );
-      APPEND_ENDL();
+      TRACE_MSG( "GetDesktopWindow()" <<  hex << _hDesktop );
+      TRACE_MSG( "!!!!!!!!!!!!!!!" <<  "PreludeWindow GA_ROOT: " << hex << _hRoot );
     }
   
   if( _hParent != _hDesktop )
     {
-      APPEND( "GetDesktopWindow()", hex << _hDesktop );
-      APPEND( "!!!!!!!!!!!!!!!", "PreludeWindow GA_PARENT: " << hex << _hParent );
+      TRACE_MSG( "GetDesktopWindow()" <<  hex << _hDesktop );
+      TRACE_MSG( "!!!!!!!!!!!!!!!" << "PreludeWindow GA_PARENT: " << hex << _hParent );
       
       HWND _hTemp;
       while( IsWindow( _hParent ) && _hParent != _hDesktop )
@@ -167,12 +160,10 @@ PreludeWindow::PreludeWindow(HeadInfo &head, BreakId break_id)
           HWND _hParent2 = (HWND)GetWindowLong( _hTemp, GWL_HWNDPARENT );
           if( _hParent == _hTemp )
             break;
-          APPEND( "!!!!!!!!!!!!!!!", hex << _hTemp << " GA_PARENT: " << hex << _hParent );
-          APPEND( "!!!!!!!!!!!!!!!", hex << _hTemp << " GWL_HWNDPARENT: " << hex << _hParent2 );
+          TRACE_MSG("!!!!!!!!!!!!!!!" << hex << _hTemp << " GA_PARENT: " << hex << _hParent);
+          TRACE_MSG("!!!!!!!!!!!!!!!" << hex << _hTemp << " GWL_HWNDPARENT: " << hex << _hParent2);
         }
-      APPEND_ENDL();
     }
-  
 #endif
 
   this->head = head;
@@ -180,6 +171,7 @@ PreludeWindow::PreludeWindow(HeadInfo &head, BreakId break_id)
     {
       Gtk::Window::set_screen(head.screen);
     }
+  TRACE_EXIT();
 }
 
 
@@ -230,7 +222,7 @@ PreludeWindow::add(Gtk::Widget& widget)
 {
   if (! window_frame)
     {
-      window_frame = manage(new Frame());
+      window_frame = Gtk::manage(new Frame());
       window_frame->set_border_width(0);
       window_frame->set_frame_style(Frame::STYLE_BREAK_WINDOW);
       Gtk::Window::add(*window_frame);
@@ -362,7 +354,7 @@ PreludeWindow::set_stage(IApp::PreludeStage stage)
           int winx, winy;
           get_position(winx, winy);
           set_position(Gtk::WIN_POS_NONE);
-          move (winx, SCREEN_MARGIN);
+          move (winx, head.get_y() + SCREEN_MARGIN);
         }
       break;
     }
@@ -447,8 +439,8 @@ PreludeWindow::avoid_pointer(int px, int py)
   TRACE_MSG("geom2" << winx << " " << winy << " " << width << " " << height << " ");
 
   int screen_height = head.get_height();
-  int top_y = SCREEN_MARGIN;
-  int bottom_y = screen_height - height - SCREEN_MARGIN;
+  int top_y = head.get_y() + SCREEN_MARGIN;
+  int bottom_y = head.get_y() + screen_height - height - SCREEN_MARGIN;
   if (winy < top_y + SCREEN_MARGIN)
     {
       winy = bottom_y;
