@@ -1,6 +1,6 @@
 // StatusIcon.cc --- Status icon
 //
-// Copyright (C) 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: StatusIcon.cc 1463 2008-03-08 17:35:31Z rcaelers $";
-
 #include "preinclude.h"
 
 #ifdef HAVE_CONFIG_H
@@ -28,6 +26,10 @@ static const char rcsid[] = "$Id: StatusIcon.cc 1463 2008-03-08 17:35:31Z rcaele
 #include <string>
 #include <assert.h>
 
+#ifdef PLATFORM_OS_OSX
+#include "ige-mac-dock.h"
+#endif
+
 #include "MainWindow.hh"
 #include "CoreFactory.hh"
 #include "StatusIcon.hh"
@@ -40,7 +42,7 @@ StatusIcon::StatusIcon(MainWindow& mw)
   // Preload icons
   const char *mode_files[] =
     {
-      "workrave-icon-large.png",
+      "workrave-icon-medium.png",
       "workrave-suspended-icon-medium.png",
       "workrave-quiet-icon-medium.png",
     };
@@ -49,7 +51,13 @@ StatusIcon::StatusIcon(MainWindow& mw)
     {
       std::string file = Util::complete_directory(mode_files[i],
                                                   Util::SEARCH_PATH_IMAGES);
-      mode_icons[i] = Gdk::Pixbuf::create_from_file(file);
+      try
+        {
+          mode_icons[i] = Gdk::Pixbuf::create_from_file(file);
+        }
+      catch(...)
+        {
+        }
     }
 
 #ifdef PLATFORM_OS_WIN32
@@ -71,6 +79,8 @@ StatusIcon::insert_icon()
   OperationMode mode = core->get_operation_mode();
   status_icon = Gtk::StatusIcon::create(mode_icons[mode]);
 
+  status_icon->signal_size_changed().connect(sigc::mem_fun(*this, &StatusIcon::on_size_changed));
+  
 #ifdef HAVE_STATUSICON_SIGNAL 
   status_icon->signal_activate().connect(sigc::mem_fun(*this, &StatusIcon::on_activate));
   status_icon->signal_popup_menu().connect(sigc::mem_fun(*this, &StatusIcon::on_popup_menu));
@@ -90,6 +100,11 @@ void StatusIcon::set_operation_mode(OperationMode m)
   status_icon->set(mode_icons[m]);
 }
 
+bool StatusIcon::is_embedded() const
+{
+  return status_icon->is_embedded();
+}
+
 void StatusIcon::on_activate()
 {
   main_window.on_activate();
@@ -103,6 +118,13 @@ void StatusIcon::on_popup_menu(guint button, guint activate_time)
   Menus::get_instance()->popup(Menus::MENU_APPLET, 1, activate_time);
 }
 
+bool StatusIcon::on_size_changed(guint size)
+{
+  (void) size;
+  main_window.status_icon_changed();
+  return true;
+}
+
 #ifndef HAVE_STATUSICON_SIGNAL 
 void StatusIcon::activate_callback(GtkStatusIcon *,
                                    gpointer callback_data)
@@ -140,3 +162,5 @@ StatusIcon::win32_filter_func (void     *xevent,
   return ret;
 }
 #endif
+
+
