@@ -1,6 +1,6 @@
 // TimeBar.cc --- Time Bar
 //
-// Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2002 - 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,9 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-
-static const char rcsid[] = "$Id: TimeBar.cc 1430 2008-01-28 22:44:29Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -37,7 +34,7 @@ static const char rcsid[] = "$Id: TimeBar.cc 1430 2008-01-28 22:44:29Z rcaelers
 #include "Text.hh"
 
 const int MARGINX = 4;
-const int MARGINY = 3;
+const int MARGINY = 2;
 const int MIN_HORIZONTAL_BAR_WIDTH = 12;
 const int MIN_HORIZONTAL_BAR_HEIGHT = 20; // stolen from gtk's progress bar
 
@@ -69,7 +66,7 @@ TimeBar::TimeBar() :
 
   set_bar_color(COLOR_ID_INACTIVE);
   set_secondary_bar_color(COLOR_ID_INACTIVE);
-  set_text_color(Gdk::Color("black"));  //
+  set_text_color(Gdk::Color("black"));
 }
 
 
@@ -83,21 +80,16 @@ void TimeBar::on_realize()
 {
   // FIXME: for some reason, the timebar get realized EACH TIME
   //        the timerbox is cycled...
-
   // We need to call the base on_realize()
   Gtk::DrawingArea::on_realize();
+
   // Now we can allocate any additional resources we need
   Glib::RefPtr<Gdk::Window> window = get_window();
   window_gc = Gdk::GC::create(window);
 
-  Glib::RefPtr<Gtk::Style> style = get_style(); // FIXME: leak??
-  Gdk::Color light = style->get_light(Gtk::STATE_NORMAL);
+  Glib::RefPtr<Gtk::Style> style = get_style();
   Gdk::Color bg = style->get_bg(Gtk::STATE_NORMAL);
-  Gdk::Color mix;
-  mix.set_red((light.get_red() + bg.get_red())/2);
-  mix.set_blue((light.get_blue() + bg.get_blue())/2);
-  mix.set_green((light.get_green() + bg.get_green())/2);
-  bar_colors[COLOR_ID_BG] = mix;
+  bar_colors[COLOR_ID_BG] = bg;
 
   Glib::RefPtr<Gdk::Colormap> colormap = get_colormap();
   for (int i = 0; i < COLOR_ID_SIZEOF; i++)
@@ -179,9 +171,18 @@ TimeBar::get_preferred_size(int &width, int &height)
 bool
 TimeBar::on_expose_event(GdkEventExpose *e)
 {
+  TRACE_ENTER("TimeBar::on_expose_event");
   const int border_size = 2;
   Gtk::Allocation allocation = get_allocation();
 
+  Glib::RefPtr<Gdk::Window> window = get_window();
+
+  Glib::RefPtr<Gdk::Colormap> colormap = get_colormap();
+  for (int i = 0; i < COLOR_ID_SIZEOF; i++)
+    {
+      colormap->alloc_color(bar_colors[i]);
+    }
+  
   // Physical width/height
   int win_w = allocation.get_width();
   int win_h = allocation.get_height();
@@ -200,13 +201,13 @@ TimeBar::on_expose_event(GdkEventExpose *e)
       win_lh = win_w;
     }
 
-  // we need a ref to the gdkmm window
-  Glib::RefPtr<Gdk::Window> window = get_window();
-
   // Border
   Gdk::Rectangle area(&e->area);
   Glib::RefPtr<Gtk::Style> style = get_style();
 
+  Gdk::Color bg = style->get_bg(Gtk::STATE_NORMAL);
+  bar_colors[COLOR_ID_BG] = bg;
+  
   // Draw background
   window_gc->set_foreground(bar_colors[COLOR_ID_BG]);
   style->paint_shadow(window, Gtk::STATE_NORMAL, Gtk::SHADOW_IN, area,
@@ -381,8 +382,12 @@ TimeBar::on_expose_event(GdkEventExpose *e)
       rect2 = down_rect;
     }
 
-  Gdk::Color textcolor = style->get_text(Gtk::STATE_NORMAL);
+  Gdk::Color textcolor = style->get_fg(Gtk::STATE_NORMAL);
 
+  TRACE_MSG(textcolor.get_red() << " " <<
+            textcolor.get_green() << " " <<
+            textcolor.get_blue());
+  
   Glib::RefPtr<Gdk::GC> window_gc1 = Gdk::GC::create(window);
 
   window_gc1->set_clip_origin(0,0);
@@ -393,6 +398,7 @@ TimeBar::on_expose_event(GdkEventExpose *e)
   window_gc1->set_foreground(textcolor);
   window_gc1->set_clip_rectangle(rect2);
   window->draw_layout(window_gc1, text_x, text_y, pl1);
+  TRACE_EXIT();
   return true;
 }
 
