@@ -1,6 +1,6 @@
 // TimerBoxGtkView.cc --- Timers Widgets
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,15 +17,15 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: TimerBoxGtkView.cc 1570 2008-07-06 18:02:47Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "preinclude.h"
 
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <iostream>
 
 #include <gtkmm/image.h>
@@ -183,15 +183,15 @@ TimerBoxGtkView::init_widgets()
           EventButton *b = new EventButton();
           b->set_relief(Gtk::RELIEF_NONE);
           b->set_border_width(0);
-          b->add(*manage(img));
+          b->add(*Gtk::manage(img));
     
-          tooltips = manage( new Gtk::Tooltips() );
+          tooltips = Gtk::manage( new Gtk::Tooltips() );
           tooltips->set_tip( *b, _("Take rest break now") );
           tooltips->enable();
 
           Menus *menus = Menus::get_instance();
 
-          b->signal_clicked().connect(sigc::mem_fun(*menus, &Menus::on_menu_restbreak_now));
+	        b->signal_clicked().connect(sigc::mem_fun(*menus, &Menus::on_menu_restbreak_now));
           b->button_pressed.connect(sigc::mem_fun(*this,
                                                   &TimerBoxGtkView::on_restbreak_button_press_event));
           w = b;
@@ -448,7 +448,7 @@ TimerBoxGtkView::set_time_bar(BreakId id,
                               TimeBar::ColorId secondary_color,
                               int secondary_val, int secondary_max)
 {
-  TRACE_ENTER_MSG("TimerBoxGtkView::set_time_bar", id);
+  TRACE_ENTER_MSG("TimerBoxGtkView::set_time_barxb", id);
 
   TRACE_MSG(text);
   TRACE_MSG(primary_val << " " << primary_max << " " << int(primary_color));
