@@ -1,6 +1,6 @@
 // WorkraveApplet.cc
 //
-// Copyright (C) 2002, 2003, 2005, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2002, 2003, 2005, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,18 +17,15 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: WorkraveApplet.c 1480 2008-03-11 19:20:14Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "credits.h"
 
-#include <gnome.h>
 #include <panel-applet.h>
 
-#include <gtk/gtkaboutdialog.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
 #define DBUS_API_SUBJECT_TO_CHANGE
@@ -39,7 +36,6 @@ static const char rcsid[] = "$Id: WorkraveApplet.c 1480 2008-03-11 19:20:14Z rca
 #include "WorkraveApplet.h"
 #include "applet-server-bindings.h"
 #include "gui-client-bindings.h"
-#include "nls.h"
 
 G_DEFINE_TYPE (WorkraveApplet, workrave_applet, G_TYPE_OBJECT);
 
@@ -352,7 +348,7 @@ verb_about(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 
   gtk_show_about_dialog(NULL,
                         "name", "Workrave",
-                        "version", VERSION,
+                        "version", PACKAGE_VERSION,
                         "copyright", workrave_copyright,
                         "website", "http://www.workrave.org",
                         "website_label", "www.workrave.org",
@@ -687,7 +683,7 @@ showlog_callback(BonoboUIComponent *ui, const char *path, Bonobo_UIComponent_Eve
 
   new_state = strcmp(state, "0") != 0;
 
-  if (1) /* FIXME: last_showlog_state != new_state) */
+  if (1)
     {
       g_applet->last_showlog_state = new_state;
 
