@@ -1,6 +1,6 @@
 // main.cc --- Main
 //
-// Copyright (C) 2001, 2002, 2003, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: main.cc 1453 2008-02-11 20:39:45Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -27,11 +25,14 @@ static const char rcsid[] = "$Id: main.cc 1453 2008-02-11 20:39:45Z rcaelers $";
 
 #include "debug.hh"
 #include <fstream>
+#include <stdio.h>
 
 #include "GUI.hh"
 #ifdef PLATFORM_OS_WIN32
+#include <io.h>
+#include <fcntl.h>
+
 #include "crashlog.h"
-#include "w32debug.hh"
 #include "dll_hell.h"
 #endif
 
@@ -40,11 +41,15 @@ extern "C" int run(int argc, char **argv);
 int
 run(int argc, char **argv)
 {
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WIN32) && !defined(PLATFORM_OS_WIN32_NATIVE)
   // Enable Windows structural exception handling.
   __try1(exception_handler);
 #endif
 
+#ifndef NDEBUG 
+  Debug::init();
+#endif
+  
   GUI *gui = new GUI(argc, argv);
 
 #if defined(PLATFORM_OS_WIN32)
@@ -55,7 +60,7 @@ run(int argc, char **argv)
 
   delete gui;
 
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WIN32) && !defined(PLATFORM_OS_WIN32_NATIVE)
   // Disable Windows structural exception handling.
   __except1;
 #endif
@@ -64,7 +69,7 @@ run(int argc, char **argv)
 }
 
 
-#if !defined(PLATFORM_OS_WIN32) || !defined(NDEBUG)
+#if (!defined(PLATFORM_OS_WIN32)) || (!defined(PLATFORM_OS_WIN32_NATIVE) && !defined(NDEBUG))
 int
 main(int argc, char **argv)
 {
@@ -82,20 +87,13 @@ int WINAPI WinMain (HINSTANCE hInstance,
                     int iCmdShow)
 {
   char *argv[] = { szCmdLine };
-  char buf[1000];
-
+  
   // InnoSetup: [...] requires that you add code to your application
   // which creates a mutex with the name you specify in this
   // directive.
   HANDLE mtx = CreateMutex(NULL, FALSE, "WorkraveMutex");
   if (mtx != NULL && GetLastError() != ERROR_ALREADY_EXISTS)
     {
-#ifdef PLATFORM_OS_WIN32
-// FIXME: debug, remove later
-      APPEND_ENDL();
-      APPEND_ENDL();
-      APPEND_DATE();
-#endif
       run(sizeof(argv)/sizeof(argv[0]), argv);
     }
   return (0);
