@@ -1,6 +1,6 @@
 // AppletWindow.cc --- Applet info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -16,8 +16,6 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-static const char rcsid[] = "$Id: W32AppletWindow.cc 1466 2008-03-08 21:06:41Z rcaelers $";
-
 #include "preinclude.h"
 
 #ifdef HAVE_CONFIG_H
@@ -56,16 +54,6 @@ W32AppletWindow::~W32AppletWindow()
 }
 
 
-AppletWindow::AppletMode
-W32AppletWindow::get_applet_mode() const
-{
-  return APPLET_W32;
-}
-
-
-
-
-
 static HWND
 RecursiveFindWindow(HWND hwnd, LPCTSTR lpClassName)
 {
