@@ -1,6 +1,6 @@
 // ExercisesPanel.cc --- Exercises panel
 //
-// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008 Raymond Penners <raymond@dotsphinx.com>
+// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009 Raymond Penners <raymond@dotsphinx.com>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -16,8 +16,6 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Id: ExercisesPanel.cc 1549 2008-06-28 21:51:43Z rcaelers $
-//
 
 #include "config.h"
 
@@ -231,14 +229,15 @@ ExercisesPanel::ExercisesPanel(Gtk::HButtonBox *dialog_action_area)
   description_text.set_editable(false);
   image_frame.add(image);
 
-  pause_button =  manage(new Gtk::Button());
+  pause_button =  Gtk::manage(new Gtk::Button());
   Gtk::Widget *description_widget;
 
   if (dialog_action_area != NULL)
     {
-      back_button =  manage(new Gtk::Button(Gtk::Stock::GO_BACK));
-      forward_button =  manage(new Gtk::Button(Gtk::Stock::GO_FORWARD));
-
+      back_button =  Gtk::manage(new Gtk::Button(Gtk::Stock::GO_BACK));
+      forward_button =  Gtk::manage(new Gtk::Button(Gtk::Stock::GO_FORWARD));
+      stop_button = NULL;
+      
       dialog_action_area->pack_start(*back_button, false, false, 0);
       dialog_action_area->pack_start(*pause_button, false, false, 0);
       dialog_action_area->pack_start(*forward_button, false, false, 0);
@@ -246,18 +245,18 @@ ExercisesPanel::ExercisesPanel(Gtk::HButtonBox *dialog_action_area)
     }
   else
     {
-      back_button = manage(GtkUtil::create_custom_stock_button
+      back_button = Gtk::manage(GtkUtil::create_custom_stock_button
                            (NULL, Gtk::Stock::GO_BACK));
-      forward_button =  manage(GtkUtil::create_custom_stock_button
+      forward_button =  Gtk::manage(GtkUtil::create_custom_stock_button
                                (NULL, Gtk::Stock::GO_FORWARD));
 
-      stop_button =  manage(GtkUtil::create_custom_stock_button
+      stop_button =  Gtk::manage(GtkUtil::create_custom_stock_button
                                          (NULL, Gtk::Stock::CLOSE));
       stop_button->signal_clicked()
         .connect(sigc::mem_fun(*this, &ExercisesPanel::on_stop));
 
-      Gtk::HBox *button_box = manage(new Gtk::HBox());
-      Gtk::Label *browse_label = manage(new Gtk::Label());
+      Gtk::HBox *button_box = Gtk::manage(new Gtk::HBox());
+      Gtk::Label *browse_label = Gtk::manage(new Gtk::Label());
       string browse_label_text = "<b>";
       browse_label_text += _("Exercises player");
       browse_label_text += ":</b>";
@@ -268,9 +267,9 @@ ExercisesPanel::ExercisesPanel(Gtk::HButtonBox *dialog_action_area)
       button_box->pack_start(*forward_button, false, false, 0);
       button_box->pack_start(*stop_button, false, false, 0);
       Gtk::Alignment *button_align
-        = manage(new Gtk::Alignment(1.0, 0.0, 0.0, 0.0));
+        = Gtk::manage(new Gtk::Alignment(1.0, 0.0, 0.0, 0.0));
       button_align->add(*button_box);
-      Gtk::VBox *description_box = manage(new Gtk::VBox());
+      Gtk::VBox *description_box = Gtk::manage(new Gtk::VBox());
       description_box->pack_start(description_scroll, true, true, 0);
       description_box->pack_start(*button_align, false, false, 0);
       description_widget = description_box;
@@ -293,14 +292,16 @@ ExercisesPanel::ExercisesPanel(Gtk::HButtonBox *dialog_action_area)
   pause_button->signal_clicked()
     .connect(sigc::mem_fun(*this, &ExercisesPanel::on_pause));
 
-#ifdef FIXME // Causes fuzzy translations...
-  tooltips = manage( new Gtk::Tooltips() );
+  tooltips = Gtk::manage( new Gtk::Tooltips() );
   tooltips->set_tip( *back_button, _("Previous exercise") );
   tooltips->set_tip( *forward_button, _("Next exercise") );
   tooltips->set_tip( *pause_button, _("Pause exercises") );
-  tooltips->set_tip( *stop_button, _("End exercises") );
+
+  if (stop_button != NULL)
+    {
+      tooltips->set_tip( *stop_button, _("End exercises") );
+    }
   tooltips->enable();
-#endif
 
   pack_start(image_frame, false, false, 0);
   pack_start(progress_bar, false, false, 0);
@@ -400,11 +401,19 @@ ExercisesPanel::refresh_sequence()
   const Exercise &exercise = *exercise_iterator;
   if (exercise_time >= seq_time && exercise.sequence.size() > 0)
     {
-      image_iterator++;
+      // FIXME: something is not right here...
       if (image_iterator == exercise.sequence.end())
         {
           image_iterator = exercise.sequence.begin();
         }
+      else
+  	    {
+          image_iterator++;
+          if (image_iterator == exercise.sequence.end())
+            {
+              image_iterator = exercise.sequence.begin();
+            }
+        }
       show_image();
       if (exercise_time != 0)
         {
@@ -469,12 +478,10 @@ ExercisesPanel::refresh_pause()
   GtkUtil::update_custom_stock_button(pause_button,
                                       standalone ? label : NULL,
                                       stock_id);
-#ifdef FIXME // Causes fuzzy translations...
   if (paused)
     tooltips->set_tip( *pause_button, _("Resume exercises"));
   else
     tooltips->set_tip( *pause_button, _("Pause exercises"));
-#endif
 }
 
 void
