@@ -1,6 +1,6 @@
 // TextGUI.cc --- The WorkRave GUI
 //
-// Copyright (C) 2001 - 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2009 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: GUI.cc 1506 2008-03-21 08:30:45Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -100,11 +98,6 @@ GUI::~GUI()
 
   delete main_window;
 
-  if (core != NULL)
-    {
-      // FIXME: cannot delete interface. delete core;
-    }
-
   TRACE_EXIT();
 }
 
@@ -186,6 +179,7 @@ GUI::terminate()
   collect_garbage();
 
   g_main_loop_quit(main_loop);
+
   TRACE_EXIT();
 }
 
@@ -277,7 +271,6 @@ GUI::init_core()
 void
 GUI::init_sound_player()
 {
-  // FIXME: Memory leak.
   sound_player = new SoundPlayer();
 }
 
@@ -287,7 +280,7 @@ GUI::core_event_notify(CoreEvent event)
 {
   TRACE_ENTER_MSG("GUI::core_event_notify", event)
   // FIXME: HACK
-  ISoundPlayer::Sound snd = (ISoundPlayer::Sound) event;
+  SoundPlayer::SoundEvent snd = (SoundPlayer::SoundEvent) event;
   if (sound_player != NULL)
     {
       TRACE_MSG("play");
